@@ -70,7 +70,7 @@ include(dirname(__FILE__).'/top.php');
 			if($plxAdmin->aCats) {
 				foreach($plxAdmin->aCats as $k=>$v) { # Pour chaque catégorie
 					$ordre = ++$num;
-					echo '<tr class="line-'.($num%2).'">';
+					echo '<tr>';
 					echo '<td><input type="checkbox" name="idCategory[]" value="'.$k.'" /><input type="hidden" name="catNum[]" value="'.$k.'" /></td>';
 					echo '<td>'.$k.'</td><td>';
 					plxUtils::printInput($k.'_name', plxUtils::strCheck($v['name']), 'text', '10-50');
@@ -133,4 +133,4 @@ include(dirname(__FILE__).'/top.php');
 eval($plxAdmin->plxPlugins->callHook('AdminCategoriesFoot'));
 # On inclut le footer
 include(dirname(__FILE__).'/foot.php');
-?>
+?>
\ No newline at end of file
