@@ -9,42 +9,42 @@
 
 include(dirname(__FILE__).'/prepend.php');
 
-# Control du token du formulaire
+# Contrôle du token du formulaire
 plxToken::validateFormToken($_POST);
 
 # Hook Plugins
 eval($plxAdmin->plxPlugins->callHook('AdminCommentsPrepend'));
 
-# Control de l'accès à la page en fonction du profil de l'utilisateur connecté
+# Contrôle de l'accès à la page en fonction du profil de l'utilisateur connecté
 $plxAdmin->checkProfil(PROFIL_ADMIN, PROFIL_MANAGER, PROFIL_MODERATOR);
 
-# validation de l'id de l'article si passé en parametre
+# validation de l'id de l'article si passé en paramètre
 if(isset($_GET['a']) AND !preg_match('/^_?[0-9]{4}$/',$_GET['a'])) {
 	plxMsg::Error(L_ERR_UNKNOWN_ARTICLE); # Article inexistant
 	header('Location: index.php');
 	exit;
 }
 
-# Suppression des commentaires selectionnes
-if(isset($_POST['selection']) AND (!empty($_POST['btn_ok1']) AND $_POST['selection'][0]=='delete') AND isset($_POST['idCom'])) {
+# Suppression des commentaires sélectionnés
+if(isset($_POST['selection']) AND !empty($_POST['btn_ok']) AND ($_POST['selection']=='delete') AND isset($_POST['idCom'])) {
 	foreach ($_POST['idCom'] as $k => $v) $plxAdmin->delCommentaire($v);
 	header('Location: comments.php'.(!empty($_GET['a'])?'?a='.$_GET['a']:''));
 	exit;
 }
-# Validation des commentaires selectionnes
-elseif(isset($_POST['selection']) AND (!empty($_POST['btn_ok1']) AND $_POST['selection'][0]=='online') AND isset($_POST['idCom'])) {
+# Validation des commentaires sélectionnés
+elseif(isset($_POST['selection']) AND !empty($_POST['btn_ok']) AND ($_POST['selection']=='online') AND isset($_POST['idCom'])) {
 	foreach ($_POST['idCom'] as $k => $v) $plxAdmin->modCommentaire($v, 'online');
 	header('Location: comments.php'.(!empty($_GET['a'])?'?a='.$_GET['a']:''));
 	exit;
 }
-# Mise hors-ligne des commentaires selectionnes
-elseif (isset($_POST['selection']) AND (!empty($_POST['btn_ok1']) AND $_POST['selection'][0]=='offline') AND isset($_POST['idCom'])) {
+# Mise hors-ligne des commentaires sélectionnés
+elseif (isset($_POST['selection']) AND !empty($_POST['btn_ok']) AND ($_POST['selection']=='offline') AND isset($_POST['idCom'])) {
 	foreach ($_POST['idCom'] as $k => $v) $plxAdmin->modCommentaire($v, 'offline');
 	header('Location: comments.php'.(!empty($_GET['a'])?'?a='.$_GET['a']:''));
 	exit;
 }
 
-# Récuperation des infos sur l'article attaché au commentaire si passé en paramètre
+# Récupération des infos sur l'article attaché au commentaire si passé en paramètre
 if(!empty($_GET['a'])) {
 	# Infos sur notre article
 	if(!$globArt = $plxAdmin->plxGlob_arts->query('/^'.$_GET['a'].'.(.*).xml$/','','sort',0,1)) {
@@ -62,7 +62,7 @@ if(!empty($_GET['a'])) {
 # On inclut le header
 include(dirname(__FILE__).'/top.php');
 
-# Récuperation du type de commentaire à afficher
+# Récupération du type de commentaire à afficher
 $_GET['sel'] = !empty($_GET['sel']) ? $_GET['sel'] : '';
 if(in_array($_GET['sel'], array('online', 'offline', 'all')))
 	$comSel = plxUtils::nullbyteRemove($_GET['sel']);
@@ -70,7 +70,18 @@ else
 	$comSel = ((isset($_SESSION['selCom']) AND !empty($_SESSION['selCom'])) ? $_SESSION['selCom'] : 'all');
 
 if(!empty($_GET['a'])) {
-	$comSelMotif = '/^[[:punct:]]?'.str_replace('_','',$_GET['a']).'.(.*).xml$/';
+	
+	switch ($comSel) {
+		case 'online':
+			$mod = '';
+			break;
+		case 'offline':
+			$mod = '_';
+			break;
+		default:
+			$mod = '[[:punct:]]?';
+	}
+	$comSelMotif = '/^'.$mod.str_replace('_','',$_GET['a']).'.(.*).xml$/';
 	$_SESSION['selCom'] = 'all';
 	$nbComPagination=$plxAdmin->nbComments($comSelMotif);
 	$h2 = '<h2>'.L_COMMENTS_ALL_LIST.'</h2>';
@@ -109,15 +120,15 @@ if(!empty($_GET['a'])) {
 function selector($comSel, $id) {
 	ob_start();
 	if($comSel=='online')
-		plxUtils::printSelect('selection[]', array(''=> L_FOR_SELECTION, 'offline' => L_COMMENT_SET_OFFLINE, '-'=>'-----', 'delete' => L_COMMENT_DELETE), '', false,'no-margin',$id);
+		plxUtils::printSelect('selection', array(''=> L_FOR_SELECTION, 'offline' => L_COMMENT_SET_OFFLINE, '-'=>'-----', 'delete' => L_COMMENT_DELETE), '', false,'no-margin',$id);
 	elseif($comSel=='offline')
-		plxUtils::printSelect('selection[]', array(''=> L_FOR_SELECTION, 'online' => L_COMMENT_SET_ONLINE, '-'=>'-----', 'delete' => L_COMMENT_DELETE), '', false,'no-margin',$id);
+		plxUtils::printSelect('selection', array(''=> L_FOR_SELECTION, 'online' => L_COMMENT_SET_ONLINE, '-'=>'-----', 'delete' => L_COMMENT_DELETE), '', false,'no-margin',$id);
 	elseif($comSel=='all')
-		plxUtils::printSelect('selection[]', array(''=> L_FOR_SELECTION, 'online' => L_COMMENT_SET_ONLINE, 'offline' => L_COMMENT_SET_OFFLINE,  '-'=>'-----','delete' => L_COMMENT_DELETE), '', false,'no-margin',$id);
+		plxUtils::printSelect('selection', array(''=> L_FOR_SELECTION, 'online' => L_COMMENT_SET_ONLINE, 'offline' => L_COMMENT_SET_OFFLINE,  '-'=>'-----','delete' => L_COMMENT_DELETE), '', false,'no-margin',$id);
 	return ob_get_clean();
 }
 
-$selector1=selector($comSel, 'id_selection1');
+$selector=selector($comSel, 'id_selection');
 
 ?>
 
@@ -130,9 +141,9 @@ $selector1=selector($comSel, 'id_selection1');
 		<ul class="menu">
 			<?php echo implode($breadcrumbs); ?>
 		</ul>
-		<?php echo $selector1 ?>
+		<?php echo $selector ?>
 		<?php echo plxToken::getTokenPostMethod() ?>
-		<input type="submit" name="btn_ok1" value="<?php echo L_OK ?>" onclick="return confirmAction(this.form, 'id_selection1', 'delete', 'idCom[]', '<?php echo L_CONFIRM_DELETE ?>')" />
+		<input type="submit" name="btn_ok" value="<?php echo L_OK ?>" onclick="return confirmAction(this.form, 'id_selection', 'delete', 'idCom[]', '<?php echo L_CONFIRM_DELETE ?>')" />
 	</div>
 
 	<?php if(isset($h3)) echo $h3 ?>
@@ -166,10 +177,10 @@ $selector1=selector($comSel, 'id_selection1');
 						$content = '<strong>'.($status==''?L_COMMENT_ONLINE:L_COMMENT_OFFLINE).'</strong>&nbsp;-&nbsp;'.$content;
 					}
 					# On génère notre ligne
-					echo '<tr class="line-'.(++$num%2).' top type-'.$plxAdmin->plxRecord_coms->f('type').'">';
+					echo '<tr class="top type-'.$plxAdmin->plxRecord_coms->f('type').'">';
 					echo '<td><input type="checkbox" name="idCom[]" value="'.$id.'" /></td>';
 					echo '<td class="datetime">'.plxDate::formatDate($plxAdmin->plxRecord_coms->f('date')).'&nbsp;</td>';
-					echo '<td>'.$content.'&nbsp;</td>';
+					echo '<td class="wrap">'.$content.'&nbsp;</td>';
 					echo '<td>'.plxUtils::strCut($plxAdmin->plxRecord_coms->f('author'),30).'&nbsp;</td>';
 					echo '<td class="action">';
 					echo '<a href="comment_new.php?c='.$id.(!empty($_GET['a'])?'&amp;a='.$_GET['a']:'').'" title="'.L_COMMENT_ANSWER.'">'.L_COMMENT_ANSWER.'</a>&nbsp;&nbsp;';
@@ -186,34 +197,41 @@ $selector1=selector($comSel, 'id_selection1');
 	</div>
 
 </form>
-<p>
+
+<p id="pagination">
 <?php
-# Hook Plugins
-eval($plxAdmin->plxPlugins->callHook('AdminCommentsPagination'));
-# Affichage de la pagination
-if($coms) { # Si on a des commentaires (hors page)
-	# Calcul des pages
-	$last_page = ceil($nbComPagination/$plxAdmin->aConf['bypage_admin_coms']);
-	if($plxAdmin->page > $last_page) $plxAdmin->page = $last_page;
-	$prev_page = $plxAdmin->page - 1;
-	$next_page = $plxAdmin->page + 1;
-	# Generation des URLs
-	$p_url = 'comments.php?page='.$prev_page.'&amp;sel='.$_SESSION['selCom'].(!empty($_GET['a'])?'&amp;a='.$_GET['a']:''); # Page precedente
-	$n_url = 'comments.php?page='.$next_page.'&amp;sel='.$_SESSION['selCom'].(!empty($_GET['a'])?'&amp;a='.$_GET['a']:''); # Page suivante
-	$l_url = 'comments.php?page='.$last_page.'&amp;sel='.$_SESSION['selCom'].(!empty($_GET['a'])?'&amp;a='.$_GET['a']:''); # Derniere page
-	$f_url = 'comments.php?page=1'.'&amp;sel='.$_SESSION['selCom'].(!empty($_GET['a'])?'&amp;a='.$_GET['a']:''); # Premiere page
-	# On effectue l'affichage
-	if($plxAdmin->page > 2) # Si la page active > 2 on affiche un lien 1ere page
-		echo '<span class="p_first"><a href="'.$f_url.'" title="'.L_PAGINATION_FIRST_TITLE.'">'.L_PAGINATION_FIRST.'</a></span>';
-	if($plxAdmin->page > 1) # Si la page active > 1 on affiche un lien page precedente
-		echo '<span class="p_prev"><a href="'.$p_url.'" title="'.L_PAGINATION_PREVIOUS_TITLE.'">'.L_PAGINATION_PREVIOUS.'</a></span>';
-	# Affichage de la page courante
-	printf('<span class="p_page">'.L_PAGINATION.'</span>',$plxAdmin->page,$last_page);
-	if($plxAdmin->page < $last_page) # Si la page active < derniere page on affiche un lien page suivante
-		echo '<span class="p_next"><a href="'.$n_url.'" title="'.L_PAGINATION_NEXT_TITLE.'">'.L_PAGINATION_NEXT.'</a></span>';
-	if(($plxAdmin->page + 1) < $last_page) # Si la page active++ < derniere page on affiche un lien derniere page
-		echo '<span class="p_last"><a href="'.$l_url.'" title="'.L_PAGINATION_LAST_TITLE.'">'.L_PAGINATION_LAST.'</a></span>';
-}
+	# Hook Plugins
+	eval($plxAdmin->plxPlugins->callHook('AdminCommentsPagination'));
+	# Affichage de la pagination
+	if($coms) { # Si on a des articles (hors page)
+		# Calcul des pages
+		$last_page = ceil($nbComPagination/$plxAdmin->aConf['bypage_admin_coms']);
+		$stop = $plxAdmin->page + 2;
+		if($stop<5) $stop=5;
+		if($stop>$last_page) $stop=$last_page;
+		$start = $stop - 4;
+		if($start<1) $start=1;
+		# Génération des URLs
+		$sel = '&amp;sel='.$_SESSION['selCom'].(!empty($_GET['a'])?'&amp;a='.$_GET['a']:'');
+		$p_url = 'comments.php?page='.($plxAdmin->page-1).$sel;
+		$n_url = 'comments.php?page='.($plxAdmin->page+1).$sel;
+		$l_url = 'comments.php?page='.$last_page.$sel;
+		$f_url = 'comments.php?page=1'.$sel;
+		# Affichage des liens de pagination
+		printf('<span class="p_page">'.L_PAGINATION.'</span>', '<input style="text-align:right;width:35px" onchange="window.location.href=\'comments.php?page=\'+this.value+\''.$sel.'\'" value="'.$plxAdmin->page.'" />', $last_page);
+		$s = $plxAdmin->page>2 ? '<a href="'.$f_url.'" title="'.L_PAGINATION_FIRST_TITLE.'">&laquo;</a>' : '&laquo;';
+		echo '<span class="p_first">'.$s.'</span>';
+		$s = $plxAdmin->page>1 ? '<a href="'.$p_url.'" title="'.L_PAGINATION_PREVIOUS_TITLE.'">&lsaquo;</a>' : '&lsaquo;';
+		echo '<span class="p_prev">'.$s.'</span>';
+		for($i=$start;$i<=$stop;$i++) {
+			$s = $i==$plxAdmin->page ? $i : '<a href="'.('comments.php?page='.$i.$sel).'" title="'.$i.'">'.$i.'</a>';
+			echo '<span class="p_current">'.$s.'</span>';
+		}
+		$s = $plxAdmin->page<$last_page ? '<a href="'.$n_url.'" title="'.L_PAGINATION_NEXT_TITLE.'">&rsaquo;</a>' : '&rsaquo;';
+		echo '<span class="p_next">'.$s.'</span>';
+		$s = $plxAdmin->page<($last_page-1) ? '<a href="'.$l_url.'" title="'.L_PAGINATION_LAST_TITLE.'">&raquo;</a>' : '&raquo;';
+		echo '<span class="p_last">'.$s.'</span>';
+	}
 ?>
 </p>
 
@@ -234,4 +252,4 @@ if($coms) { # Si on a des commentaires (hors page)
 eval($plxAdmin->plxPlugins->callHook('AdminCommentsFoot'));
 # On inclut le footer
 include(dirname(__FILE__).'/foot.php');
-?>
+?>
\ No newline at end of file
