@@ -16,7 +16,7 @@ plxToken::validateFormToken($_POST);
 eval($plxAdmin->plxPlugins->callHook('AdminIndexPrepend'));
 
 # Suppression des articles selectionnes
-if(isset($_POST['selection']) AND ((!empty($_POST['sel1']) AND $_POST['selection'][0] == 'delete') OR (!empty($_POST['sel2']) AND $_POST['selection'][1] == 'delete')) AND isset($_POST['idArt'])) {
+if(isset($_POST['selection']) AND !empty($_POST['sel']) AND ($_POST['selection']=='delete') AND isset($_POST['idArt'])) {
 	foreach ($_POST['idArt'] as $k => $v) $plxAdmin->delArticle($v);
 	header('Location: index.php');
 	exit;
@@ -77,8 +77,12 @@ case preg_match('/^[0-9]{3}$/', $_SESSION['sel_cat'])==1:
 # Nombre d'article sélectionnés
 $nbArtPagination = $plxAdmin->nbArticles($catIdSel, $userId);
 
-# Récuperation du texte à rechercher
-$_GET['artTitle'] = (!empty($_GET['artTitle']))?plxUtils::unSlash(trim(urldecode($_GET['artTitle']))):'';
+# Récupération du texte à rechercher
+$artTitle = (!empty($_GET['artTitle']))?plxUtils::unSlash(trim(urldecode($_GET['artTitle']))):'';
+if(empty($artTitle)) {
+	 $artTitle = (!empty($_POST['artTitle']))?plxUtils::unSlash(trim(urldecode($_POST['artTitle']))):'';
+}
+$_GET['artTitle'] = $artTitle;
 
 # On génère notre motif de recherche
 $motif = '/^'.$mod.'[0-9]{4}.'.$catIdSel.'.'.$userId.'.[0-9]{12}.(.*)'.plxUtils::title2filename($_GET['artTitle']).'(.*).xml$/';
@@ -125,17 +129,26 @@ include(dirname(__FILE__).'/top.php');
 		<li><a <?php echo ($_SESSION['sel_get']=='published')?'class="selected" ':'' ?>href="index.php?sel=published&amp;page=1"><?php echo L_ALL_PUBLISHED ?></a><?php echo '&nbsp;('.$plxAdmin->nbArticles('published', $userId, '').')' ?></li>
 		<li><a <?php echo ($_SESSION['sel_get']=='draft')?'class="selected" ':'' ?>href="index.php?sel=draft&amp;page=1"><?php echo L_ALL_DRAFTS ?></a><?php echo '&nbsp;('.$plxAdmin->nbArticles('draft', $userId).')' ?></li>
 		<li><a <?php echo ($_SESSION['sel_get']=='mod')?'class="selected" ':'' ?>href="index.php?sel=mod&amp;page=1"><?php echo L_ALL_AWAITING_MODERATION ?></a><?php echo '&nbsp;('.$plxAdmin->nbArticles('all', $userId, '_').')' ?></li>
-	</ul>	
+	</ul>
 	<?php
 	echo plxToken::getTokenPostMethod();
 	if($_SESSION['profil']<=PROFIL_MODERATOR) {
-		plxUtils::printSelect('selection[]', array( '' => L_FOR_SELECTION, 'delete' => L_DELETE), '', false, false, 'id_selection1');
-		echo '<input name="sel1" type="submit" value="'.L_OK.'" onclick="return confirmAction(this.form, \'id_selection1\', \'delete\', \'idArt[]\', \''.L_CONFIRM_DELETE.'\')" />&nbsp;&nbsp;&nbsp;';
+		plxUtils::printSelect('selection', array( '' => L_FOR_SELECTION, 'delete' => L_DELETE), '', false, false, 'id_selection');
+		echo '<input name="sel" type="submit" value="'.L_OK.'" onclick="return confirmAction(this.form, \'id_selection\', \'delete\', \'idArt[]\', \''.L_CONFIRM_DELETE.'\')" />&nbsp;&nbsp;&nbsp;';
 	}
 	?>
 	<?php plxUtils::printInput('page',1,'hidden'); ?>
-	<input type="text" name="artTitle" value="<?php echo plxUtils::strCheck($_GET['artTitle']) ?>" />
-	<input class="<?php echo (!empty($_GET['artTitle'])?' select':'') ?>" type="submit" value="<?php echo L_ARTICLES_SEARCH_BUTTON ?>" />
+</div>
+
+<div class="grid">
+	<div class="col sml-6">
+		<?php plxUtils::printSelect('sel_cat', $aFilterCat, $_SESSION['sel_cat']) ?>
+		<input class="<?php echo $_SESSION['sel_cat']!='all'?' select':'' ?>" type="submit" name="submit" value="<?php echo L_ARTICLES_FILTER_BUTTON ?>" />
+	</div>
+	<div class="col sml-6 text-right">
+		<input type="text" name="artTitle" value="<?php echo plxUtils::strCheck($_GET['artTitle']) ?>" />
+		<input class="<?php echo (!empty($_GET['artTitle'])?' select':'') ?>" type="submit" value="<?php echo L_ARTICLES_SEARCH_BUTTON ?>" />
+	</div>
 </div>
 
 <div class="scrollable-table">
@@ -143,15 +156,10 @@ include(dirname(__FILE__).'/top.php');
 		<thead>
 			<tr>
 				<th class="checkbox"><input type="checkbox" onclick="checkAll(this.form, 'idArt[]')" /></th>
-				<th><?php echo L_ARTICLE_ID.' '.L_ARTICLE ?></th>				
+				<th><?php echo L_ARTICLE_ID.' '.L_ARTICLE ?></th>
 				<th><?php echo L_ARTICLE_LIST_DATE ?></th>
 				<th><?php echo L_ARTICLE_LIST_TITLE ?></th>
-				<th>
-					<div style="white-space:nowrap">
-						<?php plxUtils::printSelect('sel_cat', $aFilterCat, $_SESSION['sel_cat']) ?>
-						<input class="<?php echo $_SESSION['sel_cat']!='all'?' select':'' ?>" type="submit" name="submit" value="<?php echo L_ARTICLES_FILTER_BUTTON ?>" />
-					</div>
-				</th>
+				<th><?php echo L_ARTICLE_LIST_CATEGORIES ?></th>
 				<th><?php echo L_ARTICLE_LIST_NBCOMS ?></th>
 				<th><?php echo L_ARTICLE_LIST_AUTHOR ?></th>
 				<th class="action"><?php echo L_ARTICLE_LIST_ACTION ?></th>
@@ -166,7 +174,7 @@ include(dirname(__FILE__).'/top.php');
 			$datetime = date('YmdHi');
 			while($plxAdmin->plxRecord_arts->loop()) { # Pour chaque article
 				$author = plxUtils::getValue($plxAdmin->aUsers[$plxAdmin->plxRecord_arts->f('author')]['name']);
-				$publi = (boolean)($plxAdmin->plxRecord_arts->f('date') > $datetime);
+				$publi =  (boolean)!($plxAdmin->plxRecord_arts->f('date') > $datetime);
 				# Catégories : liste des libellés de toutes les categories
 				$draft='';
 				$libCats='';
@@ -182,7 +190,7 @@ include(dirname(__FILE__).'/top.php');
 					if(sizeof($catsName)>0) {
 						$libCats = $catsName[0];
 						unset($catsName[0]);
-						if(sizeof($catsName)>0) $libCats .= ' <a class="folder"><span>'.implode(',', $catsName).'</span></a>';
+						if(sizeof($catsName)>0) $libCats .= ' <a class="folder"><span>'.implode(', ', $catsName).'</span></a>';
 					}
 					else $libCats = L_UNCLASSIFIED;
 				}
@@ -193,11 +201,11 @@ include(dirname(__FILE__).'/top.php');
 				$nbComsToValidate = $plxAdmin->getNbCommentaires('/^_'.$idArt.'.(.*).xml$/','all');
 				$nbComsValidated = $plxAdmin->getNbCommentaires('/^'.$idArt.'.(.*).xml$/','all');
 				# On affiche la ligne
-				echo '<tr class="line-'.(++$num%2).'">';
+				echo '<tr>';
 				echo '<td><input type="checkbox" name="idArt[]" value="'.$idArt.'" /></td>';
 				echo '<td>'.$idArt.'</td>';
 				echo '<td>'.plxDate::formatDate($plxAdmin->plxRecord_arts->f('date')).'&nbsp;</td>';
-				echo '<td><a href="article.php?a='.$idArt.'" title="'.L_ARTICLE_EDIT_TITLE.'">'.plxUtils::strCheck(plxUtils::strCut($plxAdmin->plxRecord_arts->f('title'),60)).'</a>'.$draft.$awaiting.'&nbsp;</td>';
+				echo '<td class="wrap"><a href="article.php?a='.$idArt.'" title="'.L_ARTICLE_EDIT_TITLE.'">'.plxUtils::strCheck($plxAdmin->plxRecord_arts->f('title')).'</a>'.$draft.$awaiting.'&nbsp;</td>';
 				echo '<td>'.$libCats.'&nbsp;</td>';
 				echo '<td><a title="'.L_NEW_COMMENTS_TITLE.'" href="comments.php?sel=offline&amp;a='.$plxAdmin->plxRecord_arts->f('numero').'&amp;page=1">'.$nbComsToValidate.'</a> / <a title="'.L_VALIDATED_COMMENTS_TITLE.'" href="comments.php?sel=online&amp;a='.$plxAdmin->plxRecord_arts->f('numero').'&amp;page=1">'.$nbComsValidated.'</a>&nbsp;</td>';
 				echo '<td>'.plxUtils::strCheck($author).'&nbsp;</td>';
@@ -218,7 +226,7 @@ include(dirname(__FILE__).'/top.php');
 
 </form>
 
-<p>
+<p id="pagination">
 	<?php
 	# Hook Plugins
 	eval($plxAdmin->plxPlugins->callHook('AdminIndexPagination'));
@@ -226,26 +234,31 @@ include(dirname(__FILE__).'/top.php');
 	if($arts) { # Si on a des articles (hors page)
 		# Calcul des pages
 		$last_page = ceil($nbArtPagination/$plxAdmin->bypage);
-		if($plxAdmin->page > $last_page) $plxAdmin->page = $last_page;
-		$prev_page = $plxAdmin->page - 1;
-		$next_page = $plxAdmin->page + 1;
-		# Generation des URLs
+		$stop = $plxAdmin->page + 2;
+		if($stop<5) $stop=5;
+		if($stop>$last_page) $stop=$last_page;
+		$start = $stop - 4;
+		if($start<1) $start=1;
+		# Génération des URLs
 		$artTitle = (!empty($_GET['artTitle'])?'&amp;artTitle='.urlencode($_GET['artTitle']):'');
-		$p_url = 'index.php?page='.$prev_page.$artTitle; # Page precedente
-		$n_url = 'index.php?page='.$next_page.$artTitle; # Page suivante
-		$l_url = 'index.php?page='.$last_page.$artTitle; # Derniere page
-		$f_url = 'index.php?page=1'.$artTitle; # Premiere page
-		# On effectue l'affichage
-		if($plxAdmin->page > 2) # Si la page active > 2 on affiche un lien 1ere page
-			echo '<span class="p_first"><a href="'.$f_url.'" title="'.L_PAGINATION_FIRST_TITLE.'">'.L_PAGINATION_FIRST.'</a></span>';
-		if($plxAdmin->page > 1) # Si la page active > 1 on affiche un lien page precedente
-			echo '<span class="p_prev"><a href="'.$p_url.'" title="'.L_PAGINATION_PREVIOUS_TITLE.'">'.L_PAGINATION_PREVIOUS.'</a></span>';
-		# Affichage de la page courante
-		printf('<span class="p_page">'.L_PAGINATION.'</span>',$plxAdmin->page,$last_page);
-		if($plxAdmin->page < $last_page) # Si la page active < derniere page on affiche un lien page suivante
-			echo '<span class="p_next"><a href="'.$n_url.'" title="'.L_PAGINATION_NEXT_TITLE.'">'.L_PAGINATION_NEXT.'</a></span>';
-		if(($plxAdmin->page + 1) < $last_page) # Si la page active++ < derniere page on affiche un lien derniere page
-			echo '<span class="p_last"><a href="'.$l_url.'" title="'.L_PAGINATION_LAST_TITLE.'">'.L_PAGINATION_LAST.'</a></span>';
+		$p_url = 'index.php?page='.($plxAdmin->page-1).$artTitle;
+		$n_url = 'index.php?page='.($plxAdmin->page+1).$artTitle;
+		$l_url = 'index.php?page='.$last_page.$artTitle;
+		$f_url = 'index.php?page=1'.$artTitle;
+		# Affichage des liens de pagination
+		printf('<span class="p_page">'.L_PAGINATION.'</span>', '<input style="text-align:right;width:35px" onchange="window.location.href=\'index.php?page=\'+this.value+\''.$artTitle.'\'" value="'.$plxAdmin->page.'" />', $last_page);
+		$s = $plxAdmin->page>2 ? '<a href="'.$f_url.'" title="'.L_PAGINATION_FIRST_TITLE.'">&laquo;</a>' : '&laquo;';
+		echo '<span class="p_first">'.$s.'</span>';
+		$s = $plxAdmin->page>1 ? '<a href="'.$p_url.'" title="'.L_PAGINATION_PREVIOUS_TITLE.'">&lsaquo;</a>' : '&lsaquo;';
+		echo '<span class="p_prev">'.$s.'</span>';
+		for($i=$start;$i<=$stop;$i++) {
+			$s = $i==$plxAdmin->page ? $i : '<a href="'.('index.php?page='.$i.$artTitle).'" title="'.$i.'">'.$i.'</a>';
+			echo '<span class="p_current">'.$s.'</span>';
+		}
+		$s = $plxAdmin->page<$last_page ? '<a href="'.$n_url.'" title="'.L_PAGINATION_NEXT_TITLE.'">&rsaquo;</a>' : '&rsaquo;';
+		echo '<span class="p_next">'.$s.'</span>';
+		$s = $plxAdmin->page<($last_page-1) ? '<a href="'.$l_url.'" title="'.L_PAGINATION_LAST_TITLE.'">&raquo;</a>' : '&raquo;';
+		echo '<span class="p_last">'.$s.'</span>';
 	}
 	?>
 </p>
@@ -255,4 +268,4 @@ include(dirname(__FILE__).'/top.php');
 eval($plxAdmin->plxPlugins->callHook('AdminIndexFoot'));
 # On inclut le footer
 include(dirname(__FILE__).'/foot.php');
-?>
+?>
\ No newline at end of file
