@@ -112,53 +112,40 @@ $curFolder = '/'.plxUtils::strCheck(basename($_SESSION['medias']).'/'.$_SESSION[
 $curFolders = explode('/', $curFolder);
 
 ?>
-<script type="text/javascript" src="<?php echo PLX_CORE ?>lib/multifiles.js"></script>
-<script type="text/javascript">
-function toggle_divs(){
-	var uploader = document.getElementById('files_uploader');
-	var manager = document.getElementById('files_manager');
-	if(uploader.style.display == 'none') {
-		uploader.style.display = 'block';
-		manager.style.display = 'none';
-	} else {
-		uploader.style.display = 'none';
-		manager.style.display = 'block';
-	}
-}
-</script>
 
 <?php eval($plxAdmin->plxPlugins->callHook('AdminMediasTop')) # Hook Plugins ?>
 
 <form action="medias.php" method="post" id="form_medias">
 
-	<div class="inline-form action-bar">
-		<h2><?php echo L_MEDIAS_TITLE ?></h2>
-		<p>
-			<?php
-			echo L_MEDIAS_DIRECTORY.' : <a href="javascript:void(0)" onclick="document.forms[0].folder.value=\'.\';document.forms[0].submit();return true;" title="'.L_PLXMEDIAS_ROOT.'">('.L_PLXMEDIAS_ROOT.')</a> / ';
-			if($curFolders) {
-				$path='';
-				foreach($curFolders as $id => $folder) {
-					if(!empty($folder) AND $id>1) {
-						$path .= $folder.'/';
-						echo '<a href="javascript:void(0)" onclick="document.forms[0].folder.value=\''.$path.'\';document.forms[0].submit();return true;" title="'.$folder.'">'.$folder.'</a> / ';
+	<div class="inline-form" id="files_manager">
+
+		<div class="inline-form action-bar">
+			<h2><?php echo L_MEDIAS_TITLE ?></h2>
+			<p>
+				<?php
+				echo L_MEDIAS_DIRECTORY.' : <a href="javascript:void(0)" onclick="document.forms[0].folder.value=\'.\';document.forms[0].submit();return true;" title="'.L_PLXMEDIAS_ROOT.'">('.L_PLXMEDIAS_ROOT.')</a> / ';
+				if($curFolders) {
+					$path='';
+					foreach($curFolders as $id => $folder) {
+						if(!empty($folder) AND $id>1) {
+							$path .= $folder.'/';
+							echo '<a href="javascript:void(0)" onclick="document.forms[0].folder.value=\''.$path.'\';document.forms[0].submit();return true;" title="'.$folder.'">'.$folder.'</a> / ';
+						}
 					}
 				}
-			}
-			?>
-		</p>
-		<?php plxUtils::printSelect('selection', $selectionList, '', false, 'no-margin', 'id_selection') ?>
-		<input type="submit" name="btn_ok" value="<?php echo L_OK ?>" onclick="return confirmAction(this.form, 'id_selection', 'delete', 'idFile[]', '<?php echo L_CONFIRM_DELETE ?>')" />
-		&nbsp;&nbsp;&nbsp;
-		<input type="submit" onclick="toggle_divs();return false" value="<?php echo L_MEDIAS_ADD_FILE ?>" />
-		<?php if(!empty($_SESSION['folder'])) { ?>
-		<input type="submit" name="btn_delete" class="red" value="<?php echo L_DELETE_FOLDER ?>" onclick="return confirm('<?php printf(L_MEDIAS_DELETE_FOLDER_CONFIRM, $curFolder) ?>')" />
-		<?php } ?>
-		<input type="hidden" name="sort" value="" />
-	</div>
+				?>
+			</p>
+			<?php plxUtils::printSelect('selection', $selectionList, '', false, 'no-margin', 'id_selection') ?>
+			<input type="submit" name="btn_ok" value="<?php echo L_OK ?>" onclick="return confirmAction(this.form, 'id_selection', 'delete', 'idFile[]', '<?php echo L_CONFIRM_DELETE ?>')" />
+			&nbsp;&nbsp;&nbsp;
+			<input type="submit" onclick="toggle_divs();return false" value="<?php echo L_MEDIAS_ADD_FILE ?>" />
+			<?php if(!empty($_SESSION['folder'])) { ?>
+			&nbsp;&nbsp;&nbsp;<input type="submit" name="btn_delete" class="red" value="<?php echo L_DELETE_FOLDER ?>" onclick="return confirm('<?php printf(L_MEDIAS_DELETE_FOLDER_CONFIRM, $curFolder) ?>')" />
+			<?php } ?>
+			<input type="hidden" name="sort" value="" />
+			<?php echo plxToken::getTokenPostMethod() ?>
+		</div>
 
-	<div class="inline-form" id="files_manager">
-		<?php echo plxToken::getTokenPostMethod() ?>
 		<div style="float:left">
 			<?php echo L_MEDIAS_FOLDER ?>&nbsp;:&nbsp;
 			<?php echo $plxMedias->contentFolder() ?>
@@ -191,17 +178,17 @@ function toggle_divs(){
 					foreach($plxMedias->aFiles as $v) { # Pour chaque fichier
 						$isImage = in_array(strtolower($v['extension']), array('.png', '.gif', '.jpg'));
 						$ordre = ++$num;
-						echo '<tr class="line-'.($num%2).'">';
+						echo '<tr>';
 						echo '<td><input type="checkbox" name="idFile[]" value="'.$v['name'].'" /></td>';
 						echo '<td class="icon">';
 						if(is_file($v['path']) AND $isImage) {
-							echo '<a onclick="this.target=\'_blank\';return true;" title="'.plxUtils::strCheck($v['name']).'" href="'.$v['path'].'"><img alt="" src="'.$v['.thumb'].'" class="thumb" /></a>';
+							echo '<a onclick="overlay(\''.$v['path'].'\');return false;" title="'.plxUtils::strCheck($v['name']).'" href="'.$v['path'].'"><img alt="" src="'.$v['.thumb'].'" class="thumb" /></a>';
 						}
 						echo '</td>';
 						echo '<td>';
-						echo '<a onclick="this.target=\'_blank\';return true;" title="'.plxUtils::strCheck($v['name']).'" href="'.$v['path'].'">'.plxUtils::strCheck($v['name']).'</a><br />';
+						echo '<a onclick="'."this.target='_blank'".'" title="'.plxUtils::strCheck($v['name']).'" href="'.$v['path'].'">'.plxUtils::strCheck($v['name']).'</a><br />';
 						if($isImage AND is_file(plxUtils::thumbName($v['path']))) {
-							echo '<a onclick="this.target=\'_blank\';return true;" title="'.L_MEDIAS_THUMB.' : '.plxUtils::strCheck($v['name']).'" href="'.plxUtils::thumbName($v['path']).'">'.L_MEDIAS_THUMB.'</a> : '.$v['thumb']['infos'][0].' x '.$v['thumb']['infos'][1]. ' ('.plxUtils::formatFilesize($v['thumb']['filesize']).')';
+							echo '<a onclick="'."this.target='_blank'".'" title="'.L_MEDIAS_THUMB.' : '.plxUtils::strCheck($v['name']).'" href="'.plxUtils::thumbName($v['path']).'">'.L_MEDIAS_THUMB.'</a> : '.$v['thumb']['infos'][0].' x '.$v['thumb']['infos'][1]. ' ('.plxUtils::formatFilesize($v['thumb']['filesize']).')';
 						}
 						echo '</td>';
 						echo '<td>'.strtoupper($v['extension']).'</td>';
@@ -227,27 +214,47 @@ function toggle_divs(){
 
 	<div id="files_uploader" style="display:none">
 
+		<div class="inline-form action-bar">
+			<h2><?php echo L_MEDIAS_TITLE ?></h2>
+			<p>
+				<?php
+				echo L_MEDIAS_DIRECTORY.' : ('.L_PLXMEDIAS_ROOT.') / ';
+				if($curFolders) {
+					$path='';
+					foreach($curFolders as $id => $folder) {
+						if(!empty($folder) AND $id>1) {
+							$path .= $folder.'/';
+							echo $folder.' / ';
+						}
+					}
+				}
+				?>
+			</p>
+			<input type="submit" name="btn_upload" id="btn_upload" value="<?php echo L_MEDIAS_SUBMIT_FILE ?>" />
+			<?php echo plxToken::getTokenPostMethod() ?>
+		</div>
+
 		<p><a class="back" href="javascript:void(0)" onclick="toggle_divs();return false"><?php echo L_MEDIAS_BACK ?></a></p>
 
 		<p><?php echo L_MEDIAS_MAX_UPOLAD_FILE ?> : <?php echo $plxMedias->maxUpload['display'] ?></p>
-		<div class="inline-form">
-			<input id="selector" type="file" name="selector" />
-			<input type="submit" name="btn_upload" id="btn_upload" value="<?php echo L_MEDIAS_SUBMIT_FILE ?>" />
-		</div>
-		<div class="files_list" id="files_list" style="margin-top: 1rem;">
+
+		<div>
+			<input id="selector_0" type="file" multiple="multiple" name="selector_0[]" />
+			<div class="files_list" id="files_list" style="margin: 1rem 0 1rem 0;"></div>
 		</div>
+
 		<div class="grid">
 			<div class="col sma-12 med-4">
 				<ul class="unstyled-list">
 					<li><?php echo L_MEDIAS_RESIZE ?>&nbsp;:&nbsp;</li>
-					<li><input type="radio" name="resize" value="" />&nbsp;<?php echo L_MEDIAS_RESIZE_NO ?></li>
+					<li><input type="radio" checked="checked" name="resize" value="" />&nbsp;<?php echo L_MEDIAS_RESIZE_NO ?></li>
 					<?php
 						foreach($img_redim as $redim) {
 							echo '<li><input type="radio" name="resize" value="'.$redim.'" />&nbsp;'.$redim.'</li>';
 						}
 					?>
 					<li>
-						<input type="radio" checked="checked" name="resize" value="<?php echo intval($plxAdmin->aConf['images_l' ]).'x'.intval($plxAdmin->aConf['images_h' ]) ?>" />&nbsp;<?php echo intval($plxAdmin->aConf['images_l' ]).'x'.intval($plxAdmin->aConf['images_h' ]) ?>
+						<input type="radio" name="resize" value="<?php echo intval($plxAdmin->aConf['images_l' ]).'x'.intval($plxAdmin->aConf['images_h' ]) ?>" />&nbsp;<?php echo intval($plxAdmin->aConf['images_l' ]).'x'.intval($plxAdmin->aConf['images_h' ]) ?>
 						&nbsp;&nbsp;(<a href="parametres_affichage.php"><?php echo L_MEDIAS_MODIFY ?>)</a>
 					</li>
 					<li>
@@ -283,19 +290,41 @@ function toggle_divs(){
 			</div>
 		</div>
 		<?php eval($plxAdmin->plxPlugins->callHook('AdminMediasUpload')) # Hook Plugins ?>
-		<?php echo plxToken::getTokenPostMethod() ?>
-		<script type="text/javascript">
-			var multi_selector = new MultiSelector(document.getElementById('files_list'), -1, '<?php echo $plxAdmin->aConf['racine'] ?>');
-			multi_selector.addElement(document.getElementById('selector'));
-		</script>
 	</div>
 
 </form>
 
+<div class="modal">
+	<input id="modal" type="checkbox" name="modal" tabindex="1">
+	<div class="modal__overlay">
+		<label for="modal">&#10006;</label>
+		<div id="modal__box" class="modal__box"></div>
+	</div>
+</div>
+
+<script>
+function toggle_divs(){
+	var uploader = document.getElementById('files_uploader');
+	var manager = document.getElementById('files_manager');
+	if(uploader.style.display == 'none') {
+		uploader.style.display = 'block';
+		manager.style.display = 'none';
+	} else {
+		uploader.style.display = 'none';
+		manager.style.display = 'block';
+	}
+}
+function overlay(content) {
+	e = document.getElementById("modal__box");
+	e.innerHTML = '<img src="'+content+'" alt="" />';
+	e = document.getElementById("modal");
+	e.click();
+}
+</script>
+
 <?php
 # Hook Plugins
 eval($plxAdmin->plxPlugins->callHook('AdminMediasFoot'));
 # On inclut le footer
 include(dirname(__FILE__).'/foot.php');
-?>
-
+?>
\ No newline at end of file
