@@ -58,7 +58,7 @@ function listFolderFiles($dir, $include, $root=''){
 	return $content;
 }
 $root = PLX_ROOT.$plxAdmin->aConf['racine_themes'].$style;
-$aTemplates=listFolderFiles($root, array('.php','.css','.htm','.html','.txt','.js'), $root);
+$aTemplates=listFolderFiles($root, array('.php','.css','.htm','.html','.txt','.js','.xml'), $root);
 
 # On récupère le contenu du fichier template
 $content = '';
@@ -72,35 +72,29 @@ if(file_exists($filename) AND filesize($filename) > 0) {
 # On inclut le header
 include(dirname(__FILE__).'/top.php');
 ?>
+<form action="parametres_edittpl.php" method="post" id="form_edittpl">
 
-<div class="action-bar">
-	<h2><?php echo L_CONFIG_EDITTPL_TITLE ?> &laquo;<?php echo plxUtils::strCheck($style) ?>&raquo;</h2>
-	<p><?php echo L_CONFIG_VIEW_PLUXML_RESSOURCES ?></p>	
-	<form class="inline-form" action="parametres_edittpl.php" method="post" id="form_select">
+	<div class="inline-form action-bar">
+		<h2><?php echo L_CONFIG_EDITTPL_TITLE ?> &laquo;<?php echo plxUtils::strCheck($style) ?>&raquo;</h2>
+		<p><?php echo L_CONFIG_VIEW_PLUXML_RESSOURCES ?></p>	
 		<?php echo plxToken::getTokenPostMethod() ?>
-		<label for="id_template"><?php echo L_CONFIG_EDITTPL_SELECT_FILE ?></label>
 		<?php plxUtils::printSelect('template', $aTemplates, $tpl); ?> 
 		<input name="load" type="submit" value="<?php echo L_CONFIG_EDITTPL_LOAD ?>" />
-	</form>
-</div>
+		&nbsp;&nbsp;&nbsp;		
+		<input name="submit" type="submit" value="<?php echo L_SAVE_FILE ?>" />
+	</div>
 
-<?php eval($plxAdmin->plxPlugins->callHook('AdminSettingsEdittplTop')) # Hook Plugins ?>
+	<?php eval($plxAdmin->plxPlugins->callHook('AdminSettingsEdittplTop')) # Hook Plugins ?>
 
-<form action="parametres_edittpl.php" method="post" id="form_file">
-	<fieldset>
-		<div class="grid">
-			<div class="col sml-12">
-				<label for="id_content"><?php echo L_CONTENT_FIELD ?>&nbsp;:</label>
-				<?php plxUtils::printInput('tpl',plxUtils::strCheck($tpl),'hidden'); ?>
-				<?php plxUtils::printArea('content',plxUtils::strCheck($content),60,20,false,'full-width'); ?>
-				<?php eval($plxAdmin->plxPlugins->callHook('AdminSettingsEdittpl')) # Hook Plugins ?>
-				<?php echo plxToken::getTokenPostMethod() ?>
-			</div>
-			<div class="col sml-12">
-				<input name="submit" type="submit" value="<?php echo L_SAVE_FILE ?>" />
-			</div>
+	<div class="grid">
+		<div class="col sml-12">
+			<label for="id_content"><?php echo L_CONTENT_FIELD ?>&nbsp;:</label>
+			<?php plxUtils::printInput('tpl',plxUtils::strCheck($tpl),'hidden'); ?>
+			<?php plxUtils::printArea('content',plxUtils::strCheck($content),60,20,false,'full-width'); ?>
+			<?php eval($plxAdmin->plxPlugins->callHook('AdminSettingsEdittpl')) # Hook Plugins ?>
 		</div>
-	</fieldset>
+	</div>
+	
 </form>
 
 <?php
