@@ -46,7 +46,7 @@ function pluginsList($plugins, $defaultLang, $type) {
 			else
 			$icon=PLX_CORE.'admin/theme/images/icon_plugin.png';
 
-			$output .= '<tr class="line-'.($num%2).' top">';
+			$output .= '<tr class="top">';
 
 				# checkbox
 				$output .= '<td>';
@@ -57,7 +57,7 @@ function pluginsList($plugins, $defaultLang, $type) {
 				$output .= '<td><img src="'.$icon.'" alt="" /></td>';
 
 				# plugin infos
-				$output .= '<td>';
+				$output .= '<td class="wrap">';
 					# message d'alerte si plugin non configuré
 					if($type AND file_exists(PLX_PLUGINS.$plugName.'/config.php') AND !file_exists(PLX_ROOT.PLX_CONFIG_PATH.'plugins/'.$plugName.'.xml')) $output .= '<span style="margin-top:5px" class="alert red float-right">'.L_PLUGIN_NO_CONFIG.'</span>';
 					# title + version
@@ -89,13 +89,15 @@ function pluginsList($plugins, $defaultLang, $type) {
 					$output .= '<a title="'.L_PLUGINS_CSS_TITLE.'" href="parametres_plugincss.php?p='.urlencode($plugName).'">'.L_PLUGINS_CSS.'</a><br />';
 					# lien aide
 					if(is_file(PLX_PLUGINS.$plugName.'/lang/'.$defaultLang.'-help.php'))
-						$output .= '<a title="'.L_PLUGINS_HELP_TITLE.'" href="parametres_pluginhelp.php?p='.urlencode($plugName).'">'.L_PLUGINS_HELP.'</a>';
+						$output .= '<a title="'.L_HELP_TITLE.'" href="parametres_help.php?help=plugin&amp;page='.urlencode($plugName).'">'.L_HELP.'</a>';
 				$output .= '</td>';
 			$output .= '</tr>';
 		}
 	}
-	else
-		$output .= '<tr><td colspan="5" class="center">'.L_NO_PLUGIN.'</td></tr>';
+	else {
+		$colspan = $_SESSION['selPlugins']=='1' ? 5 : 4;
+		$output .= '<tr><td colspan="'.$colspan.'" class="center">'.L_NO_PLUGIN.'</td></tr>';
+	}
 	return $output;
 }
 
@@ -174,4 +176,4 @@ include(dirname(__FILE__).'/top.php');
 eval($plxAdmin->plxPlugins->callHook('AdminSettingsPluginsFoot'));
 # On inclut le footer
 include(dirname(__FILE__).'/foot.php');
-?>
+?>
\ No newline at end of file
