@@ -32,7 +32,7 @@ if(!empty($_POST)) {
 # On inclut le header
 include(dirname(__FILE__).'/top.php');
 ?>
-<script type="text/javaScript">
+<script>
 function checkBox(cb) {
 	cbs=document.getElementsByName('homeStatic[]');
 	for (var i = 0; i < cbs.length; i++) {
@@ -81,7 +81,7 @@ function checkBox(cb) {
 			if($plxAdmin->aStats) {
 				foreach($plxAdmin->aStats as $k=>$v) { # Pour chaque page statique
 					$ordre = ++$num;
-					echo '<tr class="line-'.($num%2).'">';
+					echo '<tr>';
 					echo '<td><input type="checkbox" name="idStatic[]" value="'.$k.'" /><input type="hidden" name="staticNum[]" value="'.$k.'" /></td>';
 					echo '<td>'.$k.'</td><td>';
 					$selected = $plxAdmin->aConf['homestatic']==$k ? ' checked="checked"' : '';
@@ -126,8 +126,8 @@ function checkBox(cb) {
 					<td>
 					<?php
 						echo '<input type="hidden" name="staticNum[]" value="'.$new_staticid.'" />';
-						plxUtils::printInput($new_staticid.'_group', '', 'hidden', '10-100');
-						echo '</td><td>&nbsp;';
+						echo '</td><td>';
+						plxUtils::printInput($new_staticid.'_group', '', 'text', '10-100');
 						echo '</td><td>';
 						plxUtils::printInput($new_staticid.'_name', '', 'text', '10-255');
 						plxUtils::printInput($new_staticid.'_template', 'static.php', 'hidden');
