@@ -4,29 +4,36 @@ $LANG = array(
 
 'L_MENU'											=> 'Menü',
 'L_UNKNOWN_ERROR'									=> 'Unbekannter Fehler',
-'L_CONFIRM_DELETE'									=> 'Bestätigen Sie die Löschung?',
+'L_CONFIRM_DELETE'									=> 'Löschen bestätigen?',
 'L_SAVE_FILE'										=> 'Speichern Sie die Datei',
 'L_SAVE_FILE_SUCCESSFULLY'							=> 'Datei erfolgreich gespeichert',
 'L_SAVE_FILE_ERROR'									=> 'Fehler beim Speichern der Datei für',
-'L_DELETE'											=> 'Slet',
-'L_DELETE_FILE' 				    				=> 'Slet fil',
-'L_DELETE_FOLDER'				   					=> 'Slet mappe',
-'L_SAVE_SUCCESSFUL'									=> 'Daten erflogreich gespeichert',
-'L_SAVE_ERR'										=> 'Fehler während des Dateispeicherns',
+'L_REPLY'											=> 'Antworten',
+'L_REPLY_TO'										=> 'Antworten',
+'L_CANCEL'											=> 'Abbrechen',
+'L_DELETE'											=> 'Löschen',
+'L_DELETE_FILE' 				    				=> 'Datei löschen',
+'L_DELETE_FOLDER'				   					=> 'Verzeichnis löschen',
+'L_THUMBNAIL'										=> 'Vorschaubild (optional)',
+'L_THUMBNAIL_SELECTION'								=> 'Bild auswählen',
+'L_THUMBNAIL_TITLE'									=> 'Bildtitel (optional)',
+'L_THUMBNAIL_ALT'									=> 'Alternativtext des Bildes (optional)',
+'L_SAVE_SUCCESSFUL'									=> 'Daten erfolgreich gespeichert',
+'L_SAVE_ERR'										=> 'Fehler während des Speicherns',
 'L_NO_ENTRY'										=> 'Datenzugriff verboten',
-'L_ERR_USER_EMPTY'									=> 'Bitte geben Sie Benutzernamen ein',
-'L_ERR_PASSWORD_EMPTY'								=> 'Bitte geben sie ein Passwort ein',
+'L_ERR_USER_EMPTY'									=> 'Bitte Benutzernamen eingeben',
+'L_ERR_PASSWORD_EMPTY'								=> 'Bitte ein Passwort eingeben',
 'L_ERR_PASSWORD_EMPTY_CONFIRMATION'					=> 'Ungültiges oder leeres Passwort',
 'L_ERR_INVALID_EMAIL'								=> 'Ungültige E-Mail-Adresse',
 'L_ERR_INVALID_SITE'								=> 'Ungültige Adresse der Website',
-'L_ERR_INVALID_ARTICLE_IDENT'						=> 'Ungültiges Artikel-ID !',
+'L_ERR_INVALID_ARTICLE_IDENT'						=> 'Ungültige Artikel-ID!',
 'L_DEFAULT_NEW_CATEGORY_URL'						=> 'neue-kategorie',
 'L_DEFAULT_NEW_STATIC_URL'							=> 'neue-seite',
 'L_DEFAULT_NEW_ARTICLE_URL'							=> 'neuer-artikel',
 'L_ARTICLE_SAVE_SUCCESSFUL'							=> 'Artikel erfolgreich angelegt',
 'L_ARTICLE_MODIFY_SUCCESSFUL'						=> 'Artikel erfolgreich aktualisiert',
 'L_ARTICLE_DELETE_SUCCESSFUL'						=> 'Artikel erfolgreich gelöscht',
-'L_ARTICLE_SAVE_ERR'								=> 'Fehler beim Speichern des Artikels',
+'L_ARTICLE_SAVE_ERR'								=> 'Fehler beim Speichern des Artikels.',
 'L_ARTICLE_DELETE_ERR'								=> 'Fehler beim Löschen des Artikels.',
 'L_ERR_UNKNOWN_COMMENT'								=> 'Der angeforderte Kommentar existiert nicht oder nicht mehr',
 'L_COMMENT_SAVE_SUCCESSFUL'							=> 'Kommentar erfolgreich geändert',
@@ -41,7 +48,7 @@ $LANG = array(
 'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'						=> 'Der Ordner "Medias" konnte für diesen Benutzer nicht angelegt werden',
 'L_PLXMEDIAS_ROOT'									=> 'Grundverzeichnis',
 'L_PLXMEDIAS_NEW_FOLDER_ERR'						=> 'Der Ordner konnte nicht angelegt werden',
-'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'					=> 'Ordner erflogreich angelegt',
+'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'					=> 'Ordner erfolgreich angelegt',
 'L_PLXMEDIAS_NEW_FOLDER_EXISTS'						=> 'Dieser Ordner existiert bereits',
 'L_PLXMEDIAS_DEL_FOLDER_ERR'						=> 'Fehler beim Löschen den Ordners',
 'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'					=> 'Der Ordner wurde erfolgreich gelöscht',
@@ -51,7 +58,7 @@ $LANG = array(
 'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'						=> 'Die Datei wurde erfolgreich hochgeladen',
 'L_PLXMEDIAS_UPLOADS_ERR'							=> 'Fehler beim Hochladen von Dateien',
 'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'					=> 'Dateien wurden erfolgreich hochgeladen',
-'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'				=> 'Dateien wurdeb erfolgreich entfernt',
+'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'				=> 'Dateien wurden erfolgreich entfernt',
 'L_PLXMEDIAS_DELETE_FILES_ERR'						=> 'Fehler beim Löschen der Dateien',
 'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'				=> 'Die Datei wurde erfolgreich gelöscht',
 'L_PLXMEDIAS_DELETE_FILE_ERR'						=> 'Fehler beim Löschen der Datei',
@@ -114,7 +121,7 @@ $LANG = array(
 'L_ARTICLE'											=> 'artikel',
 'L_ARTICLE_ID'										=> 'ID',
 'L_AUTH_PAGE_TITLE'									=> 'Anmeldung',
-'L_LOGOUT_SUCCESSFUL'								=> 'Sie wurden erflogreich abgemeldet',
+'L_LOGOUT_SUCCESSFUL'								=> 'Sie wurden erfolgreich abgemeldet',
 'L_LOGIN_PAGE'										=> 'Administrator Anmeldung',
 'L_AUTH_LOGIN_FIELD'								=> 'Benutzer',
 'L_AUTH_PASSWORD_FIELD'								=> 'Passwort',
@@ -171,9 +178,9 @@ $LANG = array(
 'L_COMMENT_OFFLINE_BUTTON'							=> 'Offline stellen',
 'L_COMMENT_ANSWER_BUTTON'							=> 'Antworten',
 'L_COMMENT_UPDATE_BUTTON'							=> 'Aktualisieren',
-'L_ERR_ANSWER_UNKNOWN_COMMENT'						=> 'Der Kommentar,auf den Sie antworten wollen, existiert nicht oder nicht mehr!',
+'L_ERR_ANSWER_UNKNOWN_COMMENT'						=> 'Der Kommentar, auf den Sie antworten wollen, existiert nicht oder nicht mehr!',
 'L_ERR_ANSWER_OFFLINE_COMMENT'						=> 'Der Kommentar ist offline, Antworten ist nicht möglich!',
-'L_ERR_COMMENT_UNKNOWN_ARTICLE'						=> 'Der gefragte Artikel existiert nicht oder nicht mehr, Sie können keinen Kommentar erstellen!',
+'L_ERR_COMMENT_UNKNOWN_ARTICLE'						=> 'Der gefragte Artikel existiert nicht oder nicht mehr. Sie können keinen Kommentar erstellen!',
 'L_ERR_CREATING_COMMENT'							=> 'Es gab einen Fehler beim Erstellen des Kommentars',
 'L_CREATING_COMMENT_SUCCESSFUL'						=> 'Der Kommentar wurde erfolgreich erstellt',
 'L_CREATE_NEW_COMMENT'								=> 'Kommentar schreiben',
@@ -181,7 +188,7 @@ $LANG = array(
 'L_ARTICLE_COMMENTS_LIST'							=> 'Kommentare dieses Artikels (neueste zuerst)',
 'L_COMMENT_ANSWER_TITLE'							=> 'Auf diesen Kommentar antworten',
 'L_COMMENT_ANSWER'									=> 'Antworten',
-'L_COMMENTS_ONLINE_LIST'							=> 'Liste der veroffentlichten Kommentare',
+'L_COMMENTS_ONLINE_LIST'							=> 'Liste der veröffentlichten Kommentare',
 'L_COMMENTS_ALL_LIST'								=> 'Liste aller Kommentare',
 'L_COMMENT_SET_ONLINE'								=> 'Online nehmen',
 'L_COMMENT_SET_OFFLINE'								=> 'Offline nehmen',
@@ -216,7 +223,7 @@ $LANG = array(
 'L_CATEGORY_HOME'									=> 'Homepage',
 'L_CATEGORY_DRAFT'									=> 'Entwurf',
 'L_ARTICLE_VIEW'									=> 'Ansehen',
-'L_ARTICLE_VIEW_TITLE'								=> 'Den Artikel auf dem Website ansehen',
+'L_ARTICLE_VIEW_TITLE'								=> 'Den Artikel auf der Website ansehen',
 'L_ARTICLE_EDIT'									=> 'editieren',
 'L_ARTICLE_EDIT_TITLE'								=> 'Diesen Artikel bearbeiten',
 'L_NEW_COMMENTS_TITLE'								=> 'Wartende Kommentare',
@@ -333,7 +340,7 @@ $LANG = array(
 'L_PLUXML_CHECK_VERSION'							=> 'Aktualitätsprüfung von PluXml (über PluXml.org)',
 'L_PLUXML_UPDATE_UNAVAILABLE'						=> 'Update hat nicht funktioniert. Sie sollten  \'allow_url_fopen\' aktivieren.',
 'L_PLUXML_UPDATE_ERR'								=> 'Updatefunktion mit unbekanntem Fehler abgebrochen.',
-'L_PLUXML_UPTODATE'									=> 'Sie benützen die aktuelle Version von PluXml',
+'L_PLUXML_UPTODATE'									=> 'Sie benutzen die aktuellste Version von PluXml',
 'L_PLUXML_UPDATE_AVAILABLE'							=> 'Eine neue Version ist verfügbar! Sie können sie hier herunterladen: ',
 'L_CONFIG_USERS_TITLE'								=> 'Benutzerverwaltung',
 'L_CONFIG_USER'										=> 'Benutzer',
@@ -348,7 +355,7 @@ $LANG = array(
 'L_ERR_STATIC_ALREADY_EXISTS'						=> 'wird bereits verwendet',
 'L_BACK_TO_PLUGINS'									=> 'Zurück zur Plugins-Seite',
 'L_NO_PLUGIN'										=> 'Keine Plugins',
-'L_PLUGIN_NO_CONFIG'								=> 'Nicht konfiguriert plugin',
+'L_PLUGIN_NO_CONFIG'								=> 'Plugin nicht konfiguriert',
 'L_PLUGINS_CSS'										=> 'CSS-Code',
 'L_PLUGINS_CSS_TITLE'								=> 'Bearbeiten Sie den CSS-Code des Plugins',
 'L_CONTENT_FIELD_FRONTEND'							=> 'CSS-Datei-Inhalte Website',
@@ -363,9 +370,7 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'						=> 'Löschen war erfolgreich',
 'L_PLUGINS_CONFIG'									=> 'Konfiguration',
 'L_PLUGINS_CONFIG_TITLE'							=> 'Pluginkonfiguration',
-'L_PLUGINS_HELP'									=> 'Hilfe',
-'L_PLUGINS_HELP_TITLE'								=> 'Pluginshilfe aufrufen',
-'L_PLUGINS_REQUIREMENTS'							=> 'Vorraussetzungen',
+'L_PLUGINS_REQUIREMENTS'							=> 'Voraussetzungen',
 'L_PLUGINS_REQUIREMENTS_HELP'						=> 'Vorausgesetzte Plugins (installiert und aktiviert), damit dieses Plugin verwendet werden kann',
 'L_PLUGINS_REQUIREMENTS_NONE'						=> 'Kein',
 'L_PLUGINS_ALPHA_SORT'								=> 'Alphabetisch sortieren Plugins',
@@ -463,7 +468,12 @@ $LANG = array(
 'L_MENU_CONFIG_PLUGINS_TITLE'						=> 'Plugins verwalten',
 'L_MENU_CONFIG_PLUGINS'								=> 'Plugins',
 'L_ERR_URL_ALREADY_EXISTS'							=> 'Url bereits im Einsatz. Bitte ändern Sie den Wert des Feldes \'Url\'',
-
+'L_THEMES'											=> 'Themes',
+'L_THEMES_TITLE'									=> 'Verwalten von Themen',
+'L_HELP'											=> 'Hilfe',
+'L_HELP_TITLE'										=> 'Siehe Hilfe',
+'L_BACK_TO_THEMES'									=> 'Zurück Hilfe',
+'L_ERR_INVALID_DATE_CREATION'						=> 'Ungültige Erstellungsdatum',
+'L_ERR_INVALID_DATE_UPDATE'							=> 'Datum ungültig aktualisiert',	
 );
-
 ?>
\ No newline at end of file
