@@ -8,9 +8,16 @@ $LANG = array(
 'L_SAVE_FILE'												=> 'Save the file',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'File saved successfully',
 'L_SAVE_FILE_ERROR'											=> 'Error while saving file',
+'L_REPLY'													=> 'Reply',
+'L_REPLY_TO'												=> 'Reply to',
+'L_CANCEL'													=> 'Cancel',
 'L_DELETE'													=> 'Delete',
 'L_DELETE_FILE' 				    						=> 'Delete file',
 'L_DELETE_FOLDER'				   							=> 'Delete folder',
+'L_THUMBNAIL'												=> 'Thumbnail (optional)',
+'L_THUMBNAIL_SELECTION'										=> 'Select image',
+'L_THUMBNAIL_TITLE'											=> 'Image Title (optional)',
+'L_THUMBNAIL_ALT'											=> 'Alternative text of the image (optional)',
 'L_SAVE_SUCCESSFUL'											=> 'Data was succesfully saved',
 'L_SAVE_ERR'												=> 'Error while saving data',
 'L_NO_ENTRY'												=> 'No entry',
@@ -188,7 +195,7 @@ $LANG = array(
 'L_ARTICLE_COMMENTS_LIST'									=> 'Comments for this article (from most recent to the oldest)',
 'L_COMMENT_ANSWER_TITLE'									=> 'Reply to this comment',
 'L_COMMENT_ANSWER'											=> 'Answer',
-'L_COMMENTS_ARTICLE_SCOPE'									=> 'article',
+'L_COMMENTS_ARTICLE_SCOPE'									=> 'Article',
 'L_COMMENTS_GLOBAL_SCOPE'									=> 'entire site',
 'L_COMMENTS_OFFLINE_LIST'									=> 'Comments awaiting moderation',
 'L_COMMENTS_LIST_DATE'										=> 'Date',
@@ -362,8 +369,6 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Successfull deletion',
 'L_PLUGINS_CONFIG'											=> 'Configuration',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Plugin\'s configuration',
-'L_PLUGINS_HELP'											=> 'Help',
-'L_PLUGINS_HELP_TITLE'										=> 'See plugin\'s help',
 'L_PLUGINS_REQUIREMENTS'									=> 'Requirements',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Available and active plugins to activate this one',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'None',
@@ -462,6 +467,12 @@ $LANG = array(
 'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Manage plugins',
 'L_MENU_CONFIG_PLUGINS'										=> 'Plugins',
 'L_ERR_URL_ALREADY_EXISTS'									=> 'Url already in use. Please change the value of the field \'Url\'',
+'L_THEMES'													=> 'Themes',
+'L_THEMES_TITLE'											=> 'Manage themes',
+'L_HELP'													=> 'Help',
+'L_HELP_TITLE'												=> 'See help',
+'L_BACK_TO_THEMES'											=> 'Back to themes',
+'L_ERR_INVALID_DATE_CREATION'								=> 'Invalid creation date',
+'L_ERR_INVALID_DATE_UPDATE'									=> 'Invalid date updated',
 );
-
 ?>
