@@ -9,10 +9,22 @@ $LANG = array(
 'L_SAVE_FILE_SUCCESSFULLY'			=> 'Fichier enregistré avec succès',
 'L_SAVE_FILE_ERROR'					=> 'Erreur pendant l\'enregistrement du fichier',
 
+'L_REPLY'							=> 'Répondre',
+'L_REPLY_TO'						=> 'Répondre à',
+'L_CANCEL'							=> 'Annuler',
+
 'L_DELETE' 						    => 'Supprimer',
 'L_DELETE_FILE' 				    => 'Supprimer fichier',
 'L_DELETE_FOLDER'				    => 'Supprimer dossier',
 
+'L_THUMBNAIL'						=> 'Image d\'accroche (facultatif)',
+'L_THUMBNAIL_SELECTION'				=> 'Sélectionner une image',
+'L_THUMBNAIL_TITLE'					=> 'Titre de l\'image (facultatif)',
+'L_THUMBNAIL_ALT'					=> 'Texte alternatif de l\'image (facultatif)',
+
+'L_ERR_INVALID_DATE_CREATION'		=> 'Date de création invalide',
+'L_ERR_INVALID_DATE_UPDATE'			=> 'Date de mise à jour invalide',	
+
 # class.plx.admin.php
 
 'L_SAVE_SUCCESSFUL'					=> 'Enregistrement des données effectué avec succès',
@@ -31,7 +43,7 @@ $LANG = array(
 'L_ARTICLE_MODIFY_SUCCESSFUL'		=> 'Article mis à jour avec succès',
 'L_ARTICLE_DELETE_SUCCESSFUL'		=> 'Suppression effectuée avec succès',
 'L_ARTICLE_SAVE_ERR'				=> 'Erreur lors de la sauvegarde de l\'article',
-'L_ARTICLE_DELETE_ERR'				=> 'Une erreur est survenue pendant la suppression de la l\article',
+'L_ARTICLE_DELETE_ERR'				=> 'Une erreur est survenue pendant la suppression de la l\'article',
 'L_ERR_UNKNOWN_COMMENT'				=> 'Le commentaire demandé n\'existe pas ou n\'existe plus',
 'L_COMMENT_SAVE_SUCCESSFUL'			=> 'Commentaire modifié avec succès',
 'L_COMMENT_UPDATE_ERR'				=> 'Erreur lors de la mise à jour du commentaire',
@@ -41,7 +53,7 @@ $LANG = array(
 'L_COMMENT_VALIDATE_ERR'			=> 'Une erreur est survenue pendant la validation',
 'L_COMMENT_MODERATE_SUCCESSFUL'		=> 'Modération effectuée avec succès',
 'L_COMMENT_MODERATE_ERR'			=> 'Une erreur est survenue lors de la modération',
-'L_ERR_URL_ALREADY_EXISTS'			=> 'Url déjà utilisée. Veuillez modifier la valeur du champ \'Url\'',
+'L_ERR_URL_ALREADY_EXISTS'			=> 'URL déjà utilisée. Veuillez modifier la valeur du champ \'URL\'',
 
 # class.plx.media.php
 
@@ -75,7 +87,7 @@ $LANG = array(
 # article.php
 
 'L_DEFAULT_NEW_ARTICLE_TITLE'		=> 'Nouvel article',
-'L_ERR_INVALID_PUBLISHING_DATE'		=> 'Date de publication invalide.',
+'L_ERR_INVALID_PUBLISHING_DATE'		=> 'Date de publication invalide',
 'L_ERR_UNKNOWN_ARTICLE'				=> 'L\'article demandé n\'existe pas ou n\'existe plus !',
 'L_ERR_FORBIDDEN_ARTICLE'			=> 'Vous n\'avez pas les droits pour accéder à cet article !',
 'L_BACK_TO_ARTICLES'				=> 'Retour à la liste des articles',
@@ -101,7 +113,7 @@ $LANG = array(
 'L_ARTICLE_TOGGLER_TITLE' 			=> 'Liste des mots clés',
 'L_NO_TAG' 							=> 'Aucun tag',
 'L_ALLOW_COMMENTS' 					=> 'Autoriser les commentaires',
-'L_ARTICLE_URL_FIELD' 				=> 'Url',
+'L_ARTICLE_URL_FIELD' 				=> 'URL',
 'L_ARTICLE_URL_FIELD_TITLE' 		=> 'l\'URL se remplit automatiquement à la création',
 'L_ARTICLE_TEMPLATE_FIELD' 			=> 'Template',
 'L_ARTICLE_MANAGE_COMMENTS'			=> 'Gérer les commentaires',
@@ -152,7 +164,7 @@ $LANG = array(
 'L_CAT_LIST_ID' 					=> 'Identifiant',
 'L_CAT_LIST_ACTIVE'					=> 'Active',
 'L_CAT_LIST_NAME' 					=> 'Nom de la catégorie',
-'L_CAT_LIST_URL' 					=> 'Url',
+'L_CAT_LIST_URL' 					=> 'URL',
 'L_CAT_LIST_SORT' 					=> 'Tri des articles',
 'L_CAT_LIST_BYPAGE'					=> 'Nb art/page',
 'L_CAT_LIST_ORDER' 					=> 'Ordre',
@@ -193,7 +205,7 @@ $LANG = array(
 'L_COMMENT_AUTHOR_FIELD'			=> 'Auteur',
 'L_COMMENT_TYPE_FIELD'				=> 'Type de commentaire',
 'L_COMMENT_DATE_FIELD'				=> 'Date et heure de publication',
-'L_COMMENT_IP_FIELD'				=> 'Ip',
+'L_COMMENT_IP_FIELD'				=> 'IP',
 'L_COMMENT_SITE_FIELD'				=> 'Site',
 'L_COMMENT_EMAIL_FIELD'				=> 'E-mail',
 'L_COMMENT_STATUS_FIELD'			=> 'Statut',
@@ -227,7 +239,7 @@ $LANG = array(
 
 # comments.php
 
-'L_COMMENTS_ARTICLE_SCOPE' 			=> 'article',
+'L_COMMENTS_ARTICLE_SCOPE' 			=> 'Article',
 'L_COMMENTS_GLOBAL_SCOPE'			=> 'site entier',
 'L_COMMENTS_LIST_DATE'				=> 'Date',
 'L_COMMENTS_LIST_AUTHOR'			=> 'Auteur',
@@ -236,9 +248,9 @@ $LANG = array(
 'L_COMMENT_EDIT'					=> 'Éditer',
 'L_COMMENT_EDIT_TITLE'				=> 'Éditer ce commentaire',
 'L_COMMENT_DELETE'					=> 'Supprimer',
-'L_COMMENT_OFFLINE_FEEDS_TITLE'		=> 'Flux rss des commentaires hors-ligne',
+'L_COMMENT_OFFLINE_FEEDS_TITLE'		=> 'Flux RSS des commentaires hors-ligne',
 'L_COMMENT_OFFLINE_FEEDS'			=> 'Commentaires hors-ligne',
-'L_COMMENT_ONLINE_FEEDS_TITLE'		=> 'Flux rss des commentaires en-ligne',
+'L_COMMENT_ONLINE_FEEDS_TITLE'		=> 'Flux RSS des commentaires en-ligne',
 'L_COMMENT_ONLINE_FEEDS'			=> 'Commentaires en-ligne',
 'L_COMMENTS_PRIVATE_FEEDS'		    => 'Flux de syndication privés',
 'L_COMMENTS_ONLINE_LIST'			=> 'Liste des commentaires publiés',
@@ -328,10 +340,10 @@ $LANG = array(
 'L_CONFIG_VIEW_HOMESTATIC'			=> 'Utiliser une page statique comme page d\'accueil',
 'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'	=> 'Attention cette page est inactive',
 'L_CONFIG_VIEW_PLUXML_RESSOURCES'	=> 'Télécharger d\'autres thèmes sur <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
-'L_CONFIG_VIEW_BYPAGE_FEEDS'		=> 'Nombre d\'articles/commentaires affichés sur les fils Rss',
-'L_CONFIG_VIEW_FEEDS_HEADLINE'		=> 'Afficher uniquement le chapô dans les flux Rss des articles',
+'L_CONFIG_VIEW_BYPAGE_FEEDS'		=> 'Nombre d\'articles/commentaires affichés sur les fils RSS',
+'L_CONFIG_VIEW_FEEDS_HEADLINE'		=> 'Afficher uniquement le chapô dans les flux RSS des articles',
 'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'	=> 'Si le chapô est vide, le contenu est affiché',
-'L_CONFIG_VIEW_FEEDS_FOOTER'		=> 'Texte à ajouter comme signature au bas de chaque flux Rss des articles',
+'L_CONFIG_VIEW_FEEDS_FOOTER'		=> 'Texte à ajouter comme signature au bas de chaque flux RSS des articles',
 'L_CONFIG_VIEW_UPDATE'				=> 'Modifier les options d\'affichage',
 'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'	=> 'Afficher les catégories sans article',
 'L_CONFIG_HOMETEMPLATE'				=> 'Template de la page d\'accueil',
@@ -339,12 +351,12 @@ $LANG = array(
 # parametres_avances.php
 
 'L_CONFIG_ADVANCED_DESC'			=> 'Configuration avancée',
-'L_CONFIG_ADVANCED_URL_REWRITE'		=> 'Activer la réécriture d\'urls',
+'L_CONFIG_ADVANCED_URL_REWRITE'		=> 'Activer la réécriture d\'URL',
 'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'=> 'Attention un fichier .htaccess est déjà présent à la racine de votre PluXml. En activant la réécriture d\'url ce fichier sera modifié',
 'L_CONFIG_ADVANCED_GZIP'			=> 'Activer la compression GZIP',
 'L_CONFIG_ADVANCED_GZIP_HELP'		=> 'Permet de compresser les pages pour économiser de la bande passante, cependant cela peut augmenter la charge processeur',
 'L_CONFIG_ADVANCED_CAPCHA'			=> 'Activer le capcha anti-spam',
-'L_CONFIG_ADVANCED_ADMIN_KEY'		=> 'Clef d\'administration (URLs privés)',
+'L_CONFIG_ADVANCED_ADMIN_KEY'		=> 'Clef d\'administration (URL privés)',
 'L_CONFIG_ADVANCED_KEY_HELP'		=> 'Vider ce champs pour régénérer la clef',
 'L_CONFIG_ADVANCED_USERFOLDERS'		=> 'Utiliser un dossier medias différent pour chaque utilisateur',
 'L_HELP_SLASH_END'					=> 'Ne pas oublier le slash à la fin',
@@ -371,7 +383,7 @@ $LANG = array(
 'L_CONFIG_BASE_MODERATE_ARTICLES'	=> 'Modérer les articles pour les profils Rédacteur et Éditeur',
 'L_CONFIG_BASE_UPDATE'				=> 'Modifier la configuration de base',
 'L_CONFIG_META_DESCRIPTION'			=> 'Contenu de la balise meta "description" du site (optionnel)',
-'L_CONFIG_META_KEYWORDS'			=> 'Contenu de la balises meta "keywords" du site (optionnel)',
+'L_CONFIG_META_KEYWORDS'			=> 'Contenu de la balise meta "keywords" du site (optionnel)',
 
 # parametres_edittpl.php
 
@@ -411,10 +423,10 @@ $LANG = array(
 'L_BACK_TO_PLUGINS'					=> 'Retour à la page des plugins',
 'L_NO_PLUGIN'						=> 'Aucun plugin',
 'L_PLUGIN_NO_CONFIG'				=> 'Plugin non configuré',
-'L_PLUGINS_CSS'						=> 'Code css',
-'L_PLUGINS_CSS_TITLE'				=> 'Éditer le code css du plugin',
-'L_CONTENT_FIELD_FRONTEND'			=> 'Contenu fichier css site',
-'L_CONTENT_FIELD_BACKEND'			=> 'Contenu fichier css administrateur',
+'L_PLUGINS_CSS'						=> 'Code CSS',
+'L_PLUGINS_CSS_TITLE'				=> 'Éditer le code CSS du plugin',
+'L_CONTENT_FIELD_FRONTEND'			=> 'Contenu fichier CSS site',
+'L_CONTENT_FIELD_BACKEND'			=> 'Contenu fichier CSS administrateur',
 
 # parametres_plugins.php
 
@@ -446,7 +458,7 @@ $LANG = array(
 'L_PROFIL'							=> 'Profil',
 'L_PROFIL_LOGIN'					=> 'Identifiant de connexion',
 'L_PROFIL_USER'						=> 'Nom d\'utilisateur',
-'L_PROFIL_MAIL'						=> 'Adresse email',
+'L_PROFIL_MAIL'						=> 'Adresse e-mail',
 'L_PROFIL_ADMIN_LANG'				=> 'Langue utilisée dans l\'administration',
 'L_PROFIL_INFOS'					=> 'Informations',
 'L_PROFIL_UPDATE'					=> 'Modifier votre profil',
@@ -544,6 +556,10 @@ $LANG = array(
 'L_MENU_CONFIG_INFOS'				=> 'Informations',
 'L_MENU_CONFIG_PLUGINS_TITLE'		=> 'Gérer les plugins',
 'L_MENU_CONFIG_PLUGINS'				=> 'Plugins',
-
+'L_THEMES'							=> 'Thèmes',
+'L_THEMES_TITLE'					=> 'Gérer les thèmes',
+'L_HELP'							=> 'Aide',
+'L_HELP_TITLE'						=> 'Voir l\'aide',
+'L_BACK_TO_THEMES'					=> 'Retour à la page des thèmes',
 );
 ?>
