@@ -4,11 +4,14 @@ $LANG = array(
 
 'L_LANGUE'						=> 'Français',
 
+'L_DATE_CREATION'				=> 'Date de création',
+'L_DATE_UPDATE'					=> 'Date de mise à jour',
+
 # common
 'L_PLUXML_VERSION'				=> 'PluXml version',
 'L_HOMEPAGE'					=> 'Accueil',
 'L_UNCLASSIFIED'				=> 'Non classé',
-'L_INFO_PHP_VERSION'			=> 'Version de php',
+'L_INFO_PHP_VERSION'			=> 'Version de PHP',
 'L_INFO_MAGIC_QUOTES'			=> 'État des "magic quotes"',
 'L_INFO_CHARSET'				=> 'encodage',
 
@@ -76,7 +79,6 @@ $LANG = array(
 'L_MAIL_NOT_AVAILABLE'			=> 'Fonction d\'envoi de mail non disponible',
 
 # class.plx.motor.php
-'L_FILE_VERSION_REQUIRED'		=> 'Le fichier "%sversion" est nécessaire au fonctionnement de PluXml',
 'L_ARTICLE_NO_TAG'				=> 'Aucun article pour ce mot clé !',
 'L_UNKNOWN_CATEGORY'			=> 'Cette catégorie est inexistante !',
 'L_NO_ARTICLE_PAGE'				=> 'Aucun article pour cette page !',
@@ -102,14 +104,14 @@ $LANG = array(
 'L_ARTAUTHOR_UNKNOWN'			=> 'inconnu',
 'L_ARTTAGS_NONE'				=> 'aucun',
 'L_ARTCHAPO'					=> 'Lire la suite de #art_title',
-'L_ARTFEED_RSS_CATEGORY'		=> 'Fil Rss des articles de cette catégorie',
-'L_ARTFEED_RSS_TAG'				=> 'Fil Rss des articles de ce mot clé',
-'L_ARTFEED_RSS'					=> 'Fil Rss des articles',
-'L_NO_COMMENT'					=> 'aucun commentaire',
+'L_ARTFEED_RSS_CATEGORY'		=> 'Fil RSS des articles de cette catégorie',
+'L_ARTFEED_RSS_TAG'				=> 'Fil RSS des articles de ce mot clé',
+'L_ARTFEED_RSS'					=> 'Fil RSS des articles',
+'L_NO_COMMENT'					=> 'Aucun commentaire',
 'L_COMMENT'						=> 'commentaire',
 'L_COMMENTS'					=> 'commentaires',
-'L_COMFEED_RSS_ARTICLE'			=> 'Fil Rss des commentaires de cet article',
-'L_COMFEED_RSS'					=> 'Fil Rss des commentaires',
+'L_COMFEED_RSS_ARTICLE'			=> 'Fil RSS des commentaires de cet article',
+'L_COMFEED_RSS'					=> 'Fil RSS des commentaires',
 'L_STATICCONTENT_INPROCESS'		=> 'Cette page est actuellement en cours de rédaction',
 'L_SAID'						=> 'a dit',
 
