@@ -8,9 +8,16 @@ $LANG = array(
 'L_SAVE_FILE'												=> 'Salvare il file',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'File salvato con successo',
 'L_SAVE_FILE_ERROR'											=> 'Salvataggio del file per errore',
+'L_REPLY'													=> 'Rispondere',
+'L_REPLY_TO'												=> 'Rispondere',
+'L_CANCEL'													=> 'Annullare',
 'L_DELETE'													=> 'Cancella',
 'L_DELETE_FILE' 				    						=> 'Cancella il file',
 'L_DELETE_FOLDER'				   							=> 'Eliminare la cartella',
+'L_THUMBNAIL'												=> 'Miniatura (facoltativo)',
+'L_THUMBNAIL_SELECTION'										=> 'Seleziona immagine',
+'L_THUMBNAIL_TITLE'											=> 'Immagine Titolo (facoltativo)',
+'L_THUMBNAIL_ALT'											=> 'Testo alternativo dell\'immagine (facoltativo)',
 'L_SAVE_SUCCESSFUL'											=> 'Dati salvati con successo',
 'L_SAVE_ERR'												=> 'Errore durante il salvataggio dei dati',
 'L_NO_ENTRY'												=> 'Accesso non consentito',
@@ -182,7 +189,7 @@ $LANG = array(
 'L_COMMENT_ANSWER'											=> 'Rispondi',
 'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Scrivi un nuovo commento per questo articolo',
 'L_COMMENT_NEW_COMMENT'										=> 'Scrivi un nuovo commento',
-'L_COMMENTS_ARTICLE_SCOPE'									=> 'articolo',
+'L_COMMENTS_ARTICLE_SCOPE'									=> 'Articolo',
 'L_COMMENTS_GLOBAL_SCOPE'									=> 'sito intero',
 'L_COMMENTS_OFFLINE_LIST'									=> 'Lista dei commenti in attesa di pubblicazione ',
 'L_COMMENTS_LIST_DATE'										=> 'Data',
@@ -362,8 +369,6 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Cancellazione avvenuta con successo',
 'L_PLUGINS_CONFIG'											=> 'Configurazione',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Configurazione del plugin',
-'L_PLUGINS_HELP'											=> 'Aiuto',
-'L_PLUGINS_HELP_TITLE'										=> 'Vedere l\'aiuto del plugin',
 'L_PLUGINS_REQUIREMENTS'									=> 'Prerequisiti',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lista dei plugin presenti e attivi per attivare questo plugin',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Nessuno',
@@ -462,6 +467,12 @@ $LANG = array(
 'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Gestisci i plugin',
 'L_MENU_CONFIG_PLUGINS'										=> 'Plugin',
 'L_ERR_URL_ALREADY_EXISTS'									=> 'Url già in uso. Si prega di modificare il valore del campo \'Url\'',
+'L_THEMES'													=> 'Temi',
+'L_THEMES_TITLE'											=> 'Gestire i temi',
+'L_HELP'													=> 'Aiuto',
+'L_HELP_TITLE'												=> 'Vedere l\'aiuto',
+'L_BACK_TO_THEMES'											=> 'Torna alla pagina dei temi',
+'L_ERR_INVALID_DATE_CREATION'								=> 'Data di creazione non valida',
+'L_ERR_INVALID_DATE_UPDATE'									=> 'Data non valida aggiornato',
 );
-
 ?>
