@@ -4,6 +4,9 @@ $LANG = array(
 
 'L_LANGUE'						=> 'Italiano',
 
+'L_DATE_CREATION'				=> 'Data di creazione',
+'L_DATE_UPDATE'					=> 'Data aggiornamento',
+
 # common
 'L_PLUXML_VERSION'				=> 'PluXml versione',
 'L_HOMEPAGE'					=> 'Homepage',
@@ -76,7 +79,6 @@ $LANG = array(
 'L_MAIL_NOT_AVAILABLE'			=> 'Funzione di invio mail non disponible',
 
 # class.plx.motor.php
-'L_FILE_VERSION_REQUIRED'		=> 'Il file "%sversion" è necessario al funzionamento di PluXml',
 'L_ARTICLE_NO_TAG'				=> 'Nessun articolo per questo tag !',
 'L_UNKNOWN_CATEGORY'			=> 'Questa categoria non esiste !',
 'L_NO_ARTICLE_PAGE'				=> 'Nessun articolo per questa pagina !',
