@@ -8,9 +8,16 @@ $LANG = array(
 'L_SAVE_FILE'												=> 'Sla het bestand op',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'Bestand succesvol opgeslagen',
 'L_SAVE_FILE_ERROR'											=> 'Fout bij het ​​opslaan van het bestand voor',
+'L_REPLY'													=> 'Antwoord',
+'L_REPLY_TO'												=> 'Antwoord',
+'L_CANCEL'													=> 'Annuleren',
 'L_DELETE'													=> 'Verwijderen',
 'L_DELETE_FILE' 				    						=> 'Bestand verwijderen',
 'L_DELETE_FOLDER'				   							=> 'Map verwijderen',
+'L_THUMBNAIL'												=> 'Thumbnail (facultatief)',
+'L_THUMBNAIL_SELECTION'										=> 'Selecteer Afbeelding',
+'L_THUMBNAIL_TITLE'											=> 'Beeld (facultatief)',
+'L_THUMBNAIL_ALT'											=> 'Alternatieve tekst van het beeld (facultatief)',
 'L_SAVE_SUCCESSFUL'											=> 'Gegevens succesvol opgeslagen',
 'L_SAVE_ERR'												=> 'Fout bij het opslaan van de gegevens',
 'L_NO_ENTRY'												=> 'Geen toegang',
@@ -182,7 +189,7 @@ $LANG = array(
 'L_COMMENT_ANSWER'											=> 'Antwoorden',
 'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Nieuwe commentaar schrijven voor dit artikel',
 'L_COMMENT_NEW_COMMENT'										=> 'Nieuwe commentaar schrijven',
-'L_COMMENTS_ARTICLE_SCOPE'									=> 'artikel',
+'L_COMMENTS_ARTICLE_SCOPE'									=> 'Artikel',
 'L_COMMENTS_GLOBAL_SCOPE'									=> 'volledige site',
 'L_COMMENTS_OFFLINE_LIST'									=> 'Commentaar dat wacht op goedkeuring ',
 'L_COMMENTS_LIST_DATE'										=> 'Datum',
@@ -362,8 +369,6 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Verwijdering succesvl doorgevoerd',
 'L_PLUGINS_CONFIG'											=> 'Configuratie',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Configuratie van de plugin',
-'L_PLUGINS_HELP'											=> 'Hulp',
-'L_PLUGINS_HELP_TITLE'										=> 'Plugin hulp bekijken',
 'L_PLUGINS_REQUIREMENTS'									=> 'Benodigdheden',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lijst van beschikbare en actieve plugins voor deze plugin',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Geen',
@@ -462,6 +467,12 @@ $LANG = array(
 'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Plugins beheren',
 'L_MENU_CONFIG_PLUGINS'										=> 'Plugins',
 'L_ERR_URL_ALREADY_EXISTS'									=> 'Url al in gebruik. Moet u de waarde van het veld \'Url\'',
+'L_THEMES'													=> 'Thema\'s',
+'L_THEMES_TITLE'											=> 'Het beheren van thema\'s',
+'L_HELP'													=> 'Hulp',
+'L_HELP_TITLE'												=> 'Zie hulp',
+'L_BACK_TO_THEMES'											=> 'Terug naar de onderwerpen van de pagina',
+'L_ERR_INVALID_DATE_CREATION'								=> 'Ongeldige aanmaakdatum',
+'L_ERR_INVALID_DATE_UPDATE'									=> 'Ongeldige datum bijgewerkt',
 );
-
 ?>
\ No newline at end of file
