@@ -8,9 +8,16 @@ $LANG = array(
 'L_SAVE_FILE'												=> 'Salve o arquivo',
 'L_SAVE_FILE_SUCCESSFULLY'									=> 'Arquivo salvo com sucesso',
 'L_SAVE_FILE_ERROR'											=> 'Salvar o arquivo para o erro',
+'L_REPLY'													=> 'Resposta',
+'L_REPLY_TO'												=> 'Resposta',
+'L_CANCEL'													=> 'Cancelar',
 'L_DELETE'													=> 'Excluir',
 'L_DELETE_FILE' 				    						=> 'Excluir arquivo',
 'L_DELETE_FOLDER'				   							=> 'Excluir pasta',
+'L_THUMBNAIL'												=> 'Miniatura (facultativo)',
+'L_THUMBNAIL_SELECTION'										=> 'Selecionar Imagem',
+'L_THUMBNAIL_TITLE'											=> 'Título de Imagem (facultativo)',
+'L_THUMBNAIL_ALT'											=> 'Texto alternativo da imagem (facultativo)',
 'L_SAVE_SUCCESSFUL'											=> 'Grabação dos dados efectuada com sucesso',
 'L_SAVE_ERR'												=> 'Ocorreu um erro durante o processo de grabação dos dados',
 'L_NO_ENTRY'												=> 'Acesso refusado',
@@ -182,7 +189,7 @@ $LANG = array(
 'L_COMMENT_ANSWER'											=> 'Responder',
 'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Dígitar um novo comentário para este artigo',
 'L_COMMENT_NEW_COMMENT'										=> 'Dígitar um novo comentário',
-'L_COMMENTS_ARTICLE_SCOPE'									=> 'artigo',
+'L_COMMENTS_ARTICLE_SCOPE'									=> 'Artigo',
 'L_COMMENTS_GLOBAL_SCOPE'									=> 'web-site inteiro',
 'L_COMMENTS_OFFLINE_LIST'									=> 'Lista dos comentários á espera de validação ',
 'L_COMMENTS_LIST_DATE'										=> 'Data',
@@ -362,8 +369,6 @@ $LANG = array(
 'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Supressão efectuada com sucesso',
 'L_PLUGINS_CONFIG'											=> 'Configuração',
 'L_PLUGINS_CONFIG_TITLE'									=> 'Configuração do plugin',
-'L_PLUGINS_HELP'											=> 'Ajuda',
-'L_PLUGINS_HELP_TITLE'										=> 'Vêr a ajuda do plugin',
 'L_PLUGINS_REQUIREMENTS'									=> 'Nacessário',
 'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Lista dos plugins presentes e activos para activar este plugin',
 'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Nenhum',
@@ -462,6 +467,12 @@ $LANG = array(
 'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Gerir os plugins',
 'L_MENU_CONFIG_PLUGINS'										=> 'Plugins',
 'L_ERR_URL_ALREADY_EXISTS'									=> 'Url já em uso. Por favor, altere o valor do campo \'Url\'',
+'L_THEMES'													=> 'Temas',
+'L_THEMES_TITLE'											=> 'Gerenciando temas',
+'L_HELP'													=> 'Ajuda',
+'L_HELP_TITLE'												=> 'Vêr a ajuda',
+'L_BACK_TO_THEMES'											=> 'Voltar para os temas da página',
+'L_ERR_INVALID_DATE_CREATION'								=> 'Data de criação inválido',
+'L_ERR_INVALID_DATE_UPDATE'									=> 'Data inválida atualizado',
 );
-
 ?>
