@@ -167,10 +167,6 @@ RewriteCond %{REQUEST_FILENAME} !-l
 RewriteRule ^(?!feed)(.*)$ index.php?$1 [L]
 RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 </IfModule>
-<Files "version">
-	Order allow,deny
-	Deny from all
-</Files>
 # END -- Pluxml
 ';
 
@@ -611,6 +607,10 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 					$this->aStats[$static_id]['title_htmltag'] = (isset($this->aStats[$static_id]['title_htmltag'])?$this->aStats[$static_id]['title_htmltag']:'');
 					$this->aStats[$static_id]['meta_description'] = (isset($this->aStats[$static_id]['meta_description'])?$this->aStats[$static_id]['meta_description']:'');
 					$this->aStats[$static_id]['meta_keywords'] = (isset($this->aStats[$static_id]['meta_keywords'])?$this->aStats[$static_id]['meta_keywords']:'');
+					if(plxUtils::getValue($this->aStats[$static_id]['date_creation'])=='') {
+						$this->aStats[$static_id]['date_creation'] = date('YmdHi');
+						$this->aStats[$static_id]['date_update'] = date('YmdHi');
+					}
 					# Hook plugins
 					eval($this->plxPlugins->callHook('plxAdminEditStatiquesUpdate'));
 					$action = true;
@@ -648,6 +648,8 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 				$xml .= "<meta_description><![CDATA[".plxUtils::cdataCheck($static['meta_description'])."]]></meta_description>";
 				$xml .= "<meta_keywords><![CDATA[".plxUtils::cdataCheck($static['meta_keywords'])."]]></meta_keywords>";
 				$xml .= "<title_htmltag><![CDATA[".plxUtils::cdataCheck($static['title_htmltag'])."]]></title_htmltag>";
+				$xml .= "<date_creation><![CDATA[".plxUtils::cdataCheck($static['date_creation'])."]]></date_creation>";
+				$xml .= "<date_update><![CDATA[".plxUtils::cdataCheck($static['date_update'])."]]></date_update>";
 				# Hook plugins
 				eval($this->plxPlugins->callHook('plxAdminEditStatiquesXml'));
 				$xml .=	"</statique>\n";
@@ -699,6 +701,12 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		$this->aStats[$content['id']]['title_htmltag'] = trim($content['title_htmltag']);
 		$this->aStats[$content['id']]['meta_description'] = trim($content['meta_description']);
 		$this->aStats[$content['id']]['meta_keywords'] = trim($content['meta_keywords']);
+		$this->aStats[$content['id']]['date_creation'] = trim($content['date_creation_year']).trim($content['date_creation_month']).trim($content['date_creation_day']).substr(str_replace(':','',trim($content['date_creation_time'])),0,4);
+		$date_update = $content['date_update'];
+		$date_update_user = trim($content['date_update_year']).trim($content['date_update_month']).trim($content['date_update_day']).substr(str_replace(':','',trim($content['date_update_time'])),0,4);
+		$date_update = ($date_update==$date_update_user) ? date('YmdHi') : $date_update_user;
+		$this->aStats[$content['id']]['date_update'] = $date_update;
+
 		# Hook plugins
 		eval($this->plxPlugins->callHook('plxAdminEditStatique'));
 		if($this->editStatiques(null,true)) {
@@ -759,6 +767,10 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		# Hook plugins
 		if(eval($this->plxPlugins->callHook('plxAdminEditArticle'))) return;
 
+		# Formate des dates de creation et de mise à jour
+		$date_creation = $content['date_creation_year'].$content['date_creation_month'].$content['date_creation_day'].substr(str_replace(':','',$content['date_creation_time']),0,4);
+		$date_update = $content['date_update_year'].$content['date_update_month'].$content['date_update_day'].substr(str_replace(':','',$content['date_update_time']),0,4);
+		$date_update = $date_update==$content['date_update_old'] ? date('YmdHi') : $date_update;
 		# Génération du fichier XML
 		$xml = "<?xml version='1.0' encoding='".PLX_CHARSET."'?>\n";
 		$xml .= "<document>\n";
@@ -774,7 +786,14 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		$xml .= "\t".'<meta_keywords><![CDATA['.plxUtils::cdataCheck(trim($meta_keywords)).']]></meta_keywords>'."\n";
 		$title_htmltag = plxUtils::getValue($content['title_htmltag']);
 		$xml .= "\t".'<title_htmltag><![CDATA['.plxUtils::cdataCheck(trim($title_htmltag)).']]></title_htmltag>'."\n";
-
+		$thumbnail = plxUtils::getValue($content['thumbnail']);
+		$xml .= "\t".'<thumbnail><![CDATA['.plxUtils::cdataCheck(trim($thumbnail)).']]></thumbnail>'."\n";
+		$thumbnail_alt = plxUtils::getValue($content['thumbnail_alt']);
+		$xml .= "\t".'<thumbnail_alt><![CDATA['.plxUtils::cdataCheck(trim($thumbnail_alt)).']]></thumbnail_alt>'."\n";
+		$thumbnail_title = plxUtils::getValue($content['thumbnail_title']);
+		$xml .= "\t".'<thumbnail_title><![CDATA['.plxUtils::cdataCheck(trim($thumbnail_title)).']]></thumbnail_title>'."\n";
+		$xml .= "\t".'<date_creation><![CDATA['.plxUtils::cdataCheck($date_creation).']]></date_creation>'."\n";
+		$xml .= "\t".'<date_update><![CDATA['.plxUtils::cdataCheck($date_update).']]></date_update>'."\n";
 		# Hook plugins
 		eval($this->plxPlugins->callHook('plxAdminEditArticleXml'));
 		$xml .= "</document>\n";
@@ -789,7 +808,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 			$id = str_replace('_','',$id);
 
 		# On genère le nom de notre fichier
-		$time = $content['year'].$content['month'].$content['day'].substr(str_replace(':','',$content['time']),0,4);
+		$time = $content['date_publication_year'].$content['date_publication_month'].$content['date_publication_day'].substr(str_replace(':','',$content['date_publication_time']),0,4);
 		if(!preg_match('/^[0-9]{12}$/',$time)) $time = date('YmdHi'); # Check de la date au cas ou...
 		if(empty($content['catId'])) $content['catId']=array('000'); # Catégorie non classée
 		$filename = PLX_ROOT.$this->aConf['racine_articles'].$id.'.'.implode(',', $content['catId']).'.'.trim($content['author']).'.'.$time.'.'.$content['url'].'.xml';
@@ -870,19 +889,16 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		# On génère le contenu du commentaire
 		$comment=array();
 		$comment['author'] = plxUtils::strCheck($this->aUsers[$_SESSION['user']]['name']);
-		$comment['content'] = strip_tags(trim($content),'<a>,<strong>');
+		$comment['content'] = strip_tags(trim($content['content']),'<a>,<strong>');
 		$comment['site'] = $this->racine;
 		$comment['ip'] = plxUtils::getIp();
 		$comment['type'] = 'admin';
 		$comment['mail'] = $this->aUsers[$_SESSION['user']]['email'];
+		$comment['parent'] = $content['parent'];
+		$idx = $this->nextIdArtComment($artId);
 		$time = time();
-		# On genere le nom du fichier selon l'existence ou non d'un fichier du meme nom
-		$i = 0;
-		do { # On boucle en testant l'existence du fichier (cas de plusieurs commentaires/sec pour un article)
-			$i++;
-			$comment['filename'] = $artId.'.'.$time.'-'.$i.'.xml';
-		} while(file_exists($comment['filename']));
-		# On peut creer le commentaire
+		$comment['filename'] = $artId.'.'.$time.'-'.$idx.'.xml';
+		# On peut créer le commentaire
 		if($this->addCommentaire($comment)) # Commentaire OK
 			return true;
 		else
@@ -908,7 +924,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		$comment['filename'] = $id.'.xml';
 		if(!file_exists(PLX_ROOT.$this->aConf['racine_commentaires'].$comment['filename'])) # Commentaire inexistant
 			return plxMsg::Error(L_ERR_UNKNOWN_COMMENT);
-		# Controle des saisies
+		# Contrôle des saisies
 		if(trim($content['mail'])!='' AND !plxUtils::checkMail(trim($content['mail'])))
 			return plxMsg::Error(L_ERR_INVALID_EMAIL);
 		if(trim($content['site'])!='' AND !plxUtils::checkSite($content['site']))
@@ -926,6 +942,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		$comment['type'] = $com['type'];
 		$comment['mail'] = $content['mail'];
 		$comment['site'] = $content['site'];
+		$comment['parent'] = $com['parent'];
 		# Génération du nouveau nom du fichier
 		$time = explode(':', $content['time']);
 		$newtimestamp = mktime($time[0], $time[1], 0, $content['month'], $content['day'], $content['year']);
@@ -957,7 +974,7 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 		if(file_exists($filename)) {
 			unlink($filename);
 		}
-
+		# On refait un test file_exists pour savoir si unlink à fonctionner
 		if(!file_exists($filename))
 			return plxMsg::Info(L_COMMENT_DELETE_SUCCESSFUL);
 		else
@@ -1046,8 +1063,8 @@ RewriteRule ^feed\/(.*)$ feed.php?$1 [L]
 			return L_PLUXML_UPDATE_ERR;
 
 		# Comparaison
-		if(version_compare($this->version, $latest_version, ">="))
-			return L_PLUXML_UPTODATE.' ('.$this->version.')';
+		if(version_compare(PLX_VERSION, $latest_version, ">="))
+			return L_PLUXML_UPTODATE.' ('.PLX_VERSION.')';
 		else
 		 	return L_PLUXML_UPDATE_AVAILABLE.' <a href="http://www.pluxml.org/">PluXml.org</a>';
 	}
