@@ -13,7 +13,7 @@ class plxFeed extends plxMotor {
 	/**
 	 * Méthode qui se charger de créer le Singleton plxFeed
 	 *
-	 * @return	objet			return une instance de la classe plxFeed
+	 * @return	objet			retourne une instance de la classe plxFeed
 	 * @author	Stephane F
 	 **/
 	public static function getInstance(){
@@ -36,16 +36,7 @@ class plxFeed extends plxMotor {
 		$this->getConfiguration($filename);
 		# Chargement du fichier de langue
 		loadLang(PLX_CORE.'lang/'.$this->aConf['default_lang'].'/core.php');
-		# Contrôle de la présence du fichier 'version' de PluXml
-		if(!is_readable(PLX_ROOT.'version')) {
-			header('Content-Type: text/plain; charset='.PLX_CHARSET);
-			printf(utf8_decode(L_FILE_VERSION_REQUIRED), PLX_ROOT);
-			exit;
-		}
-		# chargement du n° de version de PluXml
-		$f = file(PLX_ROOT.'version');
-		$this->version = $f['0'];
-		# récupération des paramèters dans l'url
+		# récupération des paramètres dans l'url
 		$this->get = plxUtils::getGets();
 		# gestion du timezone
 		date_default_timezone_set($this->aConf['timezone']);
@@ -66,7 +57,7 @@ class plxFeed extends plxMotor {
 		$this->getCategories(path('XMLFILE_CATEGORIES'));
 		$this->getUsers(path('XMLFILE_USERS'));
 		$this->getTags(path('XMLFILE_TAGS'));
-		# Récuperation des articles appartenant aux catégories actives
+		# Récupération des articles appartenant aux catégories actives
 		$this->getActiveArts();
 		# Hook plugins
 		eval($this->plxPlugins->callHook('plxFeedConstruct'));
@@ -85,10 +76,10 @@ class plxFeed extends plxMotor {
 		# Hook plugins
 		if(eval($this->plxPlugins->callHook('plxFeedPreChauffageBegin'))) return;
 
-		if($this->get AND preg_match('#^(?:atom/|rss/)?categorie([0-9]+)/?$#',$this->get,$capture)) {
+		if($this->get AND preg_match('#^(?:atom/|rss/)?categorie([0-9]+)/?#',$this->get,$capture)) {
 			$this->mode = 'article'; # Mode du flux
 			# On récupère la catégorie cible
-			$this->cible = str_pad($capture[1],3,'0',STR_PAD_LEFT); # On complete sur 3 caracteres
+			$this->cible = str_pad($capture[1],3,'0',STR_PAD_LEFT); # On complète sur 3 caractères
 			# On modifie le motif de recherche
 			$this->motif = '/^[0-9]{4}.((?:[0-9]|home|,)*(?:'.$this->cible.')(?:[0-9]|home|,)*).[0-9]{3}.[0-9]{12}.[a-z0-9-]+.xml$/';
 		}
@@ -121,8 +112,8 @@ class plxFeed extends plxMotor {
 		}
 		elseif($this->get AND preg_match('#^(?:atom/|rss/)?commentaires/article([0-9]+)/?$#',$this->get,$capture)) {
 			$this->mode = 'commentaire'; # Mode du flux
-			# On recupere l'article cible
-			$this->cible = str_pad($capture[1],4,'0',STR_PAD_LEFT); # On complete sur 4 caracteres
+			# On récupère l'article cible
+			$this->cible = str_pad($capture[1],4,'0',STR_PAD_LEFT); # On complète sur 4 caractères
 			# On modifie le motif de recherche
 			$this->motif = '/^'.$this->cible.'.(?:[0-9]|home|,)*(?:'.$this->activeCats.'|home)(?:[0-9]|home|,)*.[0-9]{3}.[0-9]{12}.[a-z0-9-]+.xml$/';
 		}
@@ -156,7 +147,7 @@ class plxFeed extends plxMotor {
 		# Hook plugins
 		if(eval($this->plxPlugins->callHook('plxFeedDemarrageBegin'))) return;
 
-		# Flux de commentaires d'un article precis
+		# Flux de commentaires d'un article précis
 		if($this->mode == 'commentaire' AND $this->cible) {
 			if(!$this->getArticles()) { # Aucun article, on redirige
 				$this->cible = $this->cible + 0;
@@ -188,7 +179,7 @@ class plxFeed extends plxMotor {
 				header('Location: '.$this->urlRewrite('?tag/'.$this->cible.'/'));
 				exit;
 			} else {
-				$this->getArticles(); # Recupération des articles (on les parse)
+				$this->getArticles(); # Récupération des articles (on les parse)
 			}
 		}
 		# Flux d'articles
@@ -202,7 +193,7 @@ class plxFeed extends plxMotor {
 					exit;
 				}
 			}
-			$this->getArticles(); # Recupération des articles (on les parse)
+			$this->getArticles(); # Récupération des articles (on les parse)
 		}
 
 		# Selon le mode, on appelle la méthode adéquate
@@ -242,7 +233,7 @@ class plxFeed extends plxMotor {
 			$title = $this->aConf['title'];
 			$link = $this->urlRewrite();
 		}
-		# On va boucler sur les articles (si il y'en a)
+		# On va boucler sur les articles (s'il y en a)
 		if($this->plxRecord_arts) {
 			while($this->plxRecord_arts->loop()) {
 				# Traitement initial
@@ -255,7 +246,7 @@ class plxFeed extends plxMotor {
 				$content .= $this->aConf['feed_footer'];
 				$artId = $this->plxRecord_arts->f('numero') + 0;
 				$author = $this->aUsers[$this->plxRecord_arts->f('author')]['name'];
-				# On check la date de publication
+				# On vérifie la date de publication
 				if($this->plxRecord_arts->f('date') > $last_updated)
 					$last_updated = $this->plxRecord_arts->f('date');
 
@@ -274,7 +265,7 @@ class plxFeed extends plxMotor {
 		}
 
 		# On affiche le flux
-		header('Content-Type: text/xml; charset='.PLX_CHARSET);
+		header('Content-Type: application/rss+xml; charset='.PLX_CHARSET);
 		echo '<?xml version="1.0" encoding="'.PLX_CHARSET.'" ?>'."\n";
 		echo '<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:atom="http://www.w3.org/2005/Atom">'."\n";
 		echo '<channel>'."\n";
@@ -282,7 +273,7 @@ class plxFeed extends plxMotor {
 		echo "\t".'<link>'.$link.'</link>'."\n";
 		echo "\t".'<language>' . $this->aConf['default_lang'] . '</language>'."\n";
 		echo "\t".'<description>'.plxUtils::strCheck($this->aConf['description']).'</description>'."\n";
-		echo '<atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="self" type="application/rss+xml" href="'.$this->urlRewrite('feed.php?rss').'" />'."\n";
+		echo '<atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="self" type="application/rss+xml" href="'.$this->urlRewrite('feed.php?'.$this->get).'" />'."\n";
 		$last_updated = plxDate::dateIso2rfc822($last_updated);
 		echo "\t".'<lastBuildDate>'.$last_updated.'</lastBuildDate>'."\n";
 		echo "\t".'<generator>PluXml</generator>'."\n";
@@ -312,7 +303,7 @@ class plxFeed extends plxMotor {
 			$link = $this->urlRewrite();
 		}
 
-		# On va boucler sur les commentaires (si il y'en a)
+		# On va boucler sur les commentaires (s'il y en a)
 		if($this->plxRecord_coms) {
 			while($this->plxRecord_coms->loop()) {
 				# Traitement initial
@@ -329,7 +320,7 @@ class plxFeed extends plxMotor {
 						$artInfo = $this->artInfoFromFilename($this->plxGlob_arts->aFiles[$this->plxRecord_coms->f('article')]);
 						$link_com = $this->urlRewrite('?article'.$artId.'/'.$artInfo['artUrl'].'#c'.$this->plxRecord_coms->f('numero'));
 					}
-					# On check la date de publication
+					# On vérifie la date de publication
 					if($this->plxRecord_coms->f('date') > $last_updated)
 						$last_updated = $this->plxRecord_coms->f('date');
 
@@ -349,7 +340,7 @@ class plxFeed extends plxMotor {
 		}
 
 		# On affiche le flux
-		header('Content-Type: text/xml; charset='.PLX_CHARSET);
+		header('Content-Type: application/rss+xml; charset='.PLX_CHARSET);
 		echo '<?xml version="1.0" encoding="'.PLX_CHARSET.'" ?>'."\n";
 		echo '<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:atom="http://www.w3.org/2005/Atom">'."\n";
 		echo '<channel>'."\n";
@@ -388,7 +379,7 @@ class plxFeed extends plxMotor {
 			$link_feed = $this->racine.'feed.php?admin'.$this->clef.'/commentaires/en-ligne';
 		}
 
-		# On va boucler sur les commentaires (si il y'en a)
+		# On va boucler sur les commentaires (s'il y en a)
 		if($this->plxRecord_coms) {
 			while($this->plxRecord_coms->loop()) {
 				$artId = $this->plxRecord_coms->f('article') + 0;
@@ -396,7 +387,7 @@ class plxFeed extends plxMotor {
 				$title_com = $this->plxRecord_coms->f('author').' @ ';
 				$title_com .= plxDate::formatDate($this->plxRecord_coms->f('date'),'#day #num_day #month #num_year(4), #hour:#minute');
 				$link_com = $this->racine.'core/admin/comment.php?c='.$comId;
-				# On check la date de publication
+				# On vérifie la date de publication
 				if($this->plxRecord_coms->f('date') > $last_updated)
 					$last_updated = $this->plxRecord_coms->f('date');
 				# On affiche le flux dans un buffer
@@ -414,7 +405,7 @@ class plxFeed extends plxMotor {
 		}
 
 		# On affiche le flux
-		header('Content-Type: text/xml; charset='.PLX_CHARSET);
+		header('Content-Type: application/rss+xml; charset='.PLX_CHARSET);
 		echo '<?xml version="1.0" encoding="'.PLX_CHARSET.'" ?>'."\n";
 		echo '<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:atom="http://www.w3.org/2005/Atom">'."\n";
 		echo '<channel>'."\n";
