@@ -8,7 +8,6 @@
  **/
 class plxMotor {
 
-	public $version = false; # Version de PluXml
 	public $get = false; # Donnees variable GET
 	public $racine = false; # Url de PluXml
 	public $path_url = false; # chemin de l'url du site
@@ -72,21 +71,12 @@ class plxMotor {
 		$lang = isset($_SESSION['lang']) ? $_SESSION['lang'] : $this->aConf['default_lang'];
 		$this->aConf['default_lang'] = $lang;
 		loadLang(PLX_CORE.'lang/'.$lang.'/core.php');
-		# Contrôle de la présence du fichier 'version' de PluXml
-		if(!is_readable(PLX_ROOT.'version')) {
-			header('Content-Type: text/plain charset=UTF-8');
-			printf(utf8_decode(L_FILE_VERSION_REQUIRED), PLX_ROOT);
-			exit;
-		}
-		# chargement du n° de version de PluXml
-		$f = file(PLX_ROOT.'version');
-		$this->version = $f['0'];
-		# récupération des paramèters dans l'url
+		# récupération des paramètres dans l'url
 		$this->get = plxUtils::getGets();
 		# gestion du timezone
 		date_default_timezone_set($this->aConf['timezone']);
 		# On vérifie s'il faut faire une mise à jour
-		if((!isset($this->aConf['version']) OR $this->version!=$this->aConf['version']) AND !defined('PLX_UPDATER')) {
+		if((!isset($this->aConf['version']) OR PLX_VERSION!=$this->aConf['version']) AND !defined('PLX_UPDATER')) {
 			header('Location: '.PLX_ROOT.'update/index.php');
 			exit;
 		}
@@ -164,26 +154,25 @@ class plxMotor {
 			}
 		}
 		elseif($this->get AND preg_match('/^static([0-9]+)\/?([a-z0-9-]+)?/',$this->get,$capture)) {
-			$this->cible = str_pad($capture[1],3,'0',STR_PAD_LEFT); # On complete sur 3 caracteres
-			if(!empty($this->aConf['homestatic']) AND $capture[1]){
-				if($this->aConf['homestatic']==$this->cible){
-				header('Status: 301 Moved Permanently', false, 301);
-					header('Location: '.$this->urlRewrite());
-					exit();
+			$this->cible = str_pad($capture[1],3,'0',STR_PAD_LEFT); # On complète sur 3 caractères
+			if(!isset($this->aStats[$this->cible]) OR !$this->aStats[$this->cible]['active']) {
+				$this->error404(L_UNKNOWN_STATIC);
+			} else {
+				if(!empty($this->aConf['homestatic']) AND $capture[1]){
+					if($this->aConf['homestatic']==$this->cible){
+						header('Status: 301 Moved Permanently', false, 301);
+						header('Location: '.$this->urlRewrite());
+						exit();
+					}
 				}
-			}
-			if(!empty($this->aStats[$this->cible]) AND $this->aStats[$this->cible]['active'] AND $this->aStats[$this->cible]['url']==$capture[2]) {
-				$this->mode = 'static'; # Mode static
-				$this->template = $this->aStats[$this->cible]['template'];
-			}
-			elseif(isset($this->aStats[$this->cible])) { # Redirection 301
-				if($this->aStats[$this->cible]['url']!=$capture[2]) {
+				if($this->aStats[$this->cible]['url']==$capture[2]) {
+					$this->mode = 'static'; # Mode static
+					$this->template = $this->aStats[$this->cible]['template'];
+				} else {
 					header('Status: 301 Moved Permanently', false, 301);
 					header('Location: '.$this->urlRewrite('?static'.intval($this->cible).'/'.$this->aStats[$this->cible]['url']));
 					exit();
 				}
-			} else {
-				$this->error404(L_UNKNOWN_STATIC);
 			}
 		}
 		elseif($this->get AND preg_match('/^categorie([0-9]+)\/?([a-z0-9-]+)?/',$this->get,$capture)) {
@@ -312,6 +301,7 @@ class plxMotor {
 					$_SESSION['msg']['site'] = plxUtils::unSlash($_POST['site']);
 					$_SESSION['msg']['mail'] = plxUtils::unSlash($_POST['mail']);
 					$_SESSION['msg']['content'] = plxUtils::unSlash($_POST['content']);
+					$_SESSION['msg']['parent'] = plxUtils::unSlash($_POST['parent']);
 					eval($this->plxPlugins->callHook('plxMotorDemarrageCommentSessionMessage'));
 					header('Location: '.$url.'#form');
 				}
@@ -381,7 +371,7 @@ class plxMotor {
 		$this->aConf['thumbs'] = isset($this->aConf['thumbs']) ? $this->aConf['thumbs'] : 1;
 		$this->aConf['hometemplate'] = isset($this->aConf['hometemplate']) ? $this->aConf['hometemplate'] : 'home.php';
 		$this->aConf['custom_admincss_file'] = plxUtils::getValue($this->aConf['custom_admincss_file']);
-		$this->aConf['medias'] = isset($this->aConf['medias']) ? $this->aConf['medias'] : 'data/images/';		
+		$this->aConf['medias'] = isset($this->aConf['medias']) ? $this->aConf['medias'] : 'data/images/';
 		if(!defined('PLX_PLUGINS')) define('PLX_PLUGINS', PLX_ROOT.$this->aConf['racine_plugins']);
 
 	}
@@ -483,27 +473,33 @@ class plxMotor {
 			for($i=0;$i<$nb;$i++) {
 				$attributes = $values[$iTags['statique'][$i*$size]]['attributes'];
 				$number = $attributes['number'];
-				# Recuperation du nom de la page statique
+				# Récupération du nom de la page statique
 				$this->aStats[$number]['name']=plxUtils::getValue($values[$iTags['name'][$i]]['value']);
-				# Recuperation de la balise title
+				# Récupération de la balise title
 				$title_htmltag = plxUtils::getValue($iTags['title_htmltag'][$i]);
 				$this->aStats[$number]['title_htmltag']=plxUtils::getValue($values[$title_htmltag]['value']);
-				# Recuperation du meta description
+				# Récupération du meta description
 				$meta_description = plxUtils::getValue($iTags['meta_description'][$i]);
 				$this->aStats[$number]['meta_description']=plxUtils::getValue($values[$meta_description]['value']);
-				# Recuperation du meta keywords
+				# Récupération du meta keywords
 				$meta_keywords = plxUtils::getValue($iTags['meta_keywords'][$i]);
 				$this->aStats[$number]['meta_keywords']=plxUtils::getValue($values[$meta_keywords]['value']);
-				# Recuperation du groupe de la page statique
+				# Récupération du groupe de la page statique
 				$this->aStats[$number]['group']=plxUtils::getValue($values[$iTags['group'][$i]]['value']);
-				# Recuperation de l'url de la page statique
+				# Récupération de l'url de la page statique
 				$this->aStats[$number]['url']=strtolower($attributes['url']);
-				# Recuperation de l'etat de la page
+				# Récupération de l'etat de la page
 				$this->aStats[$number]['active']=intval($attributes['active']);
 				# On affiche la page statique dans le menu ?
 				$this->aStats[$number]['menu']=isset($attributes['menu'])?$attributes['menu']:'oui';
-				# recuperation du fichier template
+				# Récupération du fichier template
 				$this->aStats[$number]['template']=isset($attributes['template'])?$attributes['template']:'static.php';
+				# Récupération de la date de création
+				$date_creation = plxUtils::getValue($iTags['date_creation'][$i]);
+				$this->aStats[$number]['date_creation']=plxUtils::getValue($values[$date_creation]['value']);
+				# Récupération de la date de mise à jour
+				$date_update = plxUtils::getValue($iTags['date_update'][$i]);
+				$this->aStats[$number]['date_update']=plxUtils::getValue($values[$date_update]['value']);
 				# On verifie que la page statique existe bien
 				$file = PLX_ROOT.$this->aConf['racine_statiques'].$number.'.'.$attributes['url'].'.php';
 				# On test si le fichier est lisible
@@ -668,6 +664,9 @@ class plxMotor {
 		$meta_keywords = plxUtils::getValue($iTags['meta_keywords'][0]);
 		$art['meta_keywords'] = plxUtils::getValue($values[$meta_keywords]['value']);
 		$art['title_htmltag'] = isset($iTags['title_htmltag']) ? plxUtils::getValue($values[$iTags['title_htmltag'][0]]['value']) : '';
+		$art['thumbnail'] = isset($iTags['thumbnail']) ? plxUtils::getValue($values[$iTags['thumbnail'][0]]['value']) : '';
+		$art['thumbnail_title'] = isset($iTags['thumbnail_title']) ? plxUtils::getValue($values[$iTags['thumbnail_title'][0]]['value']) : '';
+		$art['thumbnail_alt'] = isset($iTags['thumbnail_alt']) ? plxUtils::getValue($values[$iTags['thumbnail_alt'][0]]['value']) : '';
 		# Informations obtenues en analysant le nom du fichier
 		$art['filename'] = $filename;
 		$tmp = $this->artInfoFromFilename($filename);
@@ -677,7 +676,8 @@ class plxMotor {
 		$art['url'] = $tmp['artUrl'];
 		$art['date'] = $tmp['artDate'];
 		$art['nb_com'] = $this->getNbCommentaires('/^'.$art['numero'].'.[0-9]{10}.[0-9]+.xml$/');
-
+		$art['date_creation'] = isset($iTags['date_creation']) ? plxUtils::getValue($values[$iTags['date_creation'][0]]['value']) : $art['date'];
+		$art['date_update'] = isset($iTags['date_update']) ? plxUtils::getValue($values[$iTags['date_update'][0]]['value']) : $art['date'];
 		# Hook plugins
 		eval($this->plxPlugins->callHook('plxMotorParseArticle'));
 		# On retourne le tableau
@@ -710,15 +710,17 @@ class plxMotor {
 	 **/
 	public function comInfoFromFilename($filename) {
 		# On effectue notre capture d'informations
-		if(preg_match('/([[:punct:]]?)([0-9]{4}).([0-9]{10})-([0-9])+.xml$/',$filename,$capture)) {
+		if(preg_match('/([[:punct:]]?)([0-9]{4}).([0-9]{10})-([0-9]+).xml$/',$filename,$capture)) {
 			return array(
 				'comStatus'	=> $capture[1],
 				'artId'		=> $capture[2],
 				'comDate'	=> plxDate::timestamp2Date($capture[3]),
 				'comId'		=> $capture[3].'-'.$capture[4],
-				'comIdx'	=> $capture[4]
+				'comIdx'	=> $capture[4],
+
 			);
 		}
+		return false;
 	}
 
 	/**
@@ -747,18 +749,43 @@ class plxMotor {
 		$com['mail'] = plxUtils::getValue($values[$iTags['mail'][0]]['value']);
 		$com['site'] = plxUtils::getValue($values[$iTags['site'][0]]['value']);
 		$com['content'] = trim($values[ $iTags['content'][0] ]['value']);
+		$com['parent'] = isset($iTags['parent'])?plxUtils::getValue($values[$iTags['parent'][0]]['value']):'';
 		# Informations obtenues en analysant le nom du fichier
 		$tmp = $this->comInfoFromFilename(basename($filename));
 		$com['status'] = $tmp['comStatus'];
 		$com['numero'] = $tmp['comId'];
 		$com['article'] = $tmp['artId'];
 		$com['date'] = $tmp['comDate'];
+		$com['index'] = $tmp['comIdx'];
 		# Hook plugins
 		eval($this->plxPlugins->callHook('plxMotorParseCommentaire'));
 		# On retourne le tableau
 		return $com;
 	}
 
+	/**
+	 * Méthode qui trie récursivement les commentaires d'un article en fonction des parents
+	 *
+	 * @return	array	liste des commentaires triés
+	 * @author	Stéphane F.
+	 **/
+	public function parentChildSort_r($idField, $parentField, $els, $parentID = 0, &$result = array(), &$level = 0){
+		foreach ($els as $key => $value) {
+			if ($value[$parentField] == $parentID) {
+				$value['level'] = $level;
+				array_push($result, $value);
+				unset($els[$key]);
+				$oldParent = $parentID;
+				$parentID = $value[$idField];
+				$level++;
+				$this->parentChildSort_r($idField,$parentField, $els, $parentID, $result, $level);
+				$parentID = $oldParent;
+				$level--;
+			}
+		}
+		return $result;
+	}
+
 	/**
 	 * Méthode qui enregistre dans un objet plxRecord tous les commentaires
 	 * respectant le motif $motif et la limite $limite
@@ -769,22 +796,52 @@ class plxMotor {
 	 * @param	limite	nombre de commentaires à retourner
 	 * @param	publi	before, after ou all => on récupère tous les fichiers (date) ?
 	 * @return	null
-	 * @author	Florent MONTHEL
+	 * @author	Florent MONTHEL, Stephane F
 	 **/
 	public function getCommentaires($motif,$ordre='sort',$start=0,$limite=false,$publi='before') {
 
-		# On recupère les fichiers des commentaires
+		# On récupère les fichiers des commentaires
 		$aFiles = $this->plxGlob_coms->query($motif,'com',$ordre,$start,$limite,$publi);
 		if($aFiles) { # On a des fichiers
-			foreach($aFiles as $k=>$v) # On parcourt tous les fichiers
-				$array[ $k ] = $this->parseCommentaire(PLX_ROOT.$this->aConf['racine_commentaires'].$v);
+			foreach($aFiles as $k=>$v)
+				$array[$k] = $this->parseCommentaire(PLX_ROOT.$this->aConf['racine_commentaires'].$v);
+
+			# hiérarchisation et indentation des commentaires seulement sur les écrans requis
+			if( !(defined('PLX_ADMIN') OR defined('PLX_FEED')) OR preg_match('/comment_new/',basename($_SERVER['SCRIPT_NAME']))) {
+				$array = $this->parentChildSort_r('index', 'parent', $array);
+			}
+
 			# On stocke les enregistrements dans un objet plxRecord
 			$this->plxRecord_coms = new plxRecord($array);
+
 			return true;
 		}
 		else return false;
 	}
 
+	/**
+	 *  Méthode qui retourne le prochain id d'un commentaire pour un article précis
+	 *
+	 * @param	idArt		id de l'article
+	 * @return	string		id d'un nouveau commentaire
+	 * @author	Stephane F.
+	 **/
+	 public function nextIdArtComment($idArt) {
+
+		$ret = '0';
+		if($dh = opendir(PLX_ROOT.$this->aConf['racine_commentaires'])) {
+			$Idxs = array();
+			while(false !== ($file = readdir($dh))) {
+				if(preg_match("/_?".$idArt.".[0-9]+-([0-9]+).xml/", $file, $capture)) {
+					if ($capture[1] > $ret)
+						$ret = $capture[1];
+				}
+			}
+			closedir($dh);
+		}
+		return $ret+1;
+	}
+
 	/**
 	 * Méthode qui crée un nouveau commentaire pour l'article $artId
 	 *
@@ -794,44 +851,54 @@ class plxMotor {
 	 * @author	Florent MONTHEL, Stéphane F
 	 **/
 	public function newCommentaire($artId,$content) {
+
 		# Hook plugins
 		if(eval($this->plxPlugins->callHook('plxMotorNewCommentaire'))) return;
-		# On verifie que le capcha est correct
+
+		if(strtolower($_SERVER['REQUEST_METHOD'])!= 'post' OR !isset($_SESSION["capcha_token"]) OR !isset($_POST['capcha_token']) OR ($_SESSION["capcha_token"]!=$_POST['capcha_token'])) {
+			return L_NEWCOMMENT_ERR_ANTISPAM;
+		}
+
+		# On vérifie que le capcha est correct
 		if($this->aConf['capcha'] == 0 OR $_SESSION['capcha'] == sha1($content['rep'])) {
 			if(!empty($content['name']) AND !empty($content['content'])) { # Les champs obligatoires sont remplis
 				$comment=array();
 				$comment['type'] = 'normal';
 				$comment['author'] = plxUtils::strCheck(trim($content['name']));
 				$comment['content'] = plxUtils::strCheck(trim($content['content']));
-				# On verifie le mail
+				# On vérifie le mail
 				$comment['mail'] = (plxUtils::checkMail(trim($content['mail'])))?trim($content['mail']):'';
-				# On verifie le site
+				# On vérifie le site
 				$comment['site'] = (plxUtils::checkSite($content['site'])?$content['site']:'');
-				# On recupere l'adresse IP du posteur
+				# On récupère l'adresse IP du posteur
 				$comment['ip'] = plxUtils::getIp();
-				# On genere le nom du fichier selon l'existence ou non d'un fichier du meme nom
+				# index du commentaire
+				$idx = $this->nextIdArtComment($idArt);
+				# Commentaire parent en cas de réponse
+				if(isset($content['parent']) AND !empty($content['parent'])) {
+					$comment['parent'] = intval($content['parent']);
+				} else {
+					$comment['parent'] = '';
+				}
+				# On génère le nom du fichier
 				$time = time();
-				$i = 0;
-				do { # On boucle en testant l'existence du fichier (cas de plusieurs commentaires/sec pour un article)
-					$i++;
-					if($this->aConf['mod_com']) # On modere le commentaire => underscore
-						$comment['filename'] = '_'.$artId.'.'.$time.'-'.$i.'.xml';
-					else # On publie le commentaire directement
-						$comment['filename'] =$artId.'.'.$time.'-'.$i.'.xml';
-				} while(file_exists(PLX_ROOT.$this->aConf['racine_commentaires'].$comment['filename']));
-				# On peut creer le commentaire
+				if($this->aConf['mod_com']) # On modère le commentaire => underscore
+					$comment['filename'] = '_'.$artId.'.'.$time.'-'.$idx.'.xml';
+				else # On publie le commentaire directement
+					$comment['filename'] = $artId.'.'.$time.'-'.$idx.'.xml';
+				# On peut créer le commentaire
 				if($this->addCommentaire($comment)) { # Commentaire OK
-					if($this->aConf['mod_com']) # En cours de moderation
+					if($this->aConf['mod_com']) # En cours de modération
 						return 'mod';
 					else # Commentaire publie directement, on retourne son identifiant
-						return 'c'.$time.'-'.$i;
+						return 'c'.$artId.'-'.$idx;
 				} else { # Erreur lors de la création du commentaire
 					return L_NEWCOMMENT_ERR;
 				}
 			} else { # Erreur de remplissage des champs obligatoires
 				return L_NEWCOMMENT_FIELDS_REQUIRED;
 			}
-		} else { # Erreur de verification capcha
+		} else { # Erreur de vérification capcha
 			return L_NEWCOMMENT_ERR_ANTISPAM;
 		}
 	}
@@ -855,6 +922,7 @@ class plxMotor {
 		$xml .= "\t<mail><![CDATA[".plxUtils::cdataCheck($content['mail'])."]]></mail>\n";
 		$xml .= "\t<site><![CDATA[".plxUtils::cdataCheck($content['site'])."]]></site>\n";
 		$xml .= "\t<content><![CDATA[".plxUtils::cdataCheck($content['content'])."]]></content>\n";
+		$xml .= "\t<parent><![CDATA[".plxUtils::cdataCheck($content['parent'])."]]></parent>\n";
 		# Hook plugins
 		eval($this->plxPlugins->callHook('plxMotorAddCommentaireXml'));
 		$xml .= "</comment>\n";
