@@ -76,7 +76,7 @@ class plxPlugins {
 	 * Méthode qui execute les hooks des plugins
 	 *
 	 * @param	hookname	nom du hook à appliquer
-	 * @param	parms			parametre ou liste de paramètres sous forme de array
+	 * @param	parms		parametre ou liste de paramètres sous forme de array
 	 * @return	null
 	 * @author	Stephane F
 	 **/
@@ -84,7 +84,11 @@ class plxPlugins {
 		if(isset($this->aHooks[$hookName])) {
 			ob_start();
 			foreach($this->aHooks[$hookName] as $callback) {
-				$return = $this->aPlugins[$callback['class']]->$callback['method']($parms);
+				if($callback['class']=='=SHORTCODE=') {
+					echo $callback['method'];
+				} else {
+					$return = $this->aPlugins[$callback['class']]->{$callback['method']}($parms);
+				}
 			}
 			if(isset($return))
 				return array('?>'.ob_get_clean().'<?php ', $return);
@@ -597,5 +601,35 @@ class plxPlugin {
 		}
 	}
 
+	/**
+	 * Méthode qui retourne le chemin relatif du dossier du plugin
+	 *
+	 * @return	string		chemin vers le dossier du plugin
+	 * @author	Stephane F
+	 **/
+	public function REL_PATH() {
+		return PLX_PLUGINS.get_class($this).'/';
+	}
+	
+	/**
+	 * Méthode qui retourne le chemin absolu du dossier du plugin
+	 *
+	 * @return	string		chemin vers le dossier du plugin
+	 * @author	Stephane F
+	 **/
+	public function ABS_PATH() {
+		return str_replace(PLX_ROOT, '', $this->REL_PATH());
+	}
+
+	/**
+	 * Méthode qui retourne l'url du dossier du plugin (avec le http://)
+	 *
+	 * @return	string		url vers le dossier du plugin
+	 * @author	Stephane F
+	 **/
+	public function URL() {
+		return plxUtils::getRacine().$this->ABS_PATH();
+	}
+
 }
-?>
\ No newline at end of file
+?>
