@@ -423,65 +423,128 @@ class plxUtils {
 	/**
 	 * Méthode qui crée la miniature d'une image
 	 *
-	 * @param	filename			emplacement et nom du fichier source
-	 * @param	filename_out		emplacement et nom de la miniature créée
-	 * @param	width				largeur de la miniature
-	 * @param	height				hauteur de la miniature
-	 * @param	quality				qualité de l'image
-	 * @param	ratio				si vrai conserve le ratio largeur x hauteur
-	 * @return	boolean				vrai si image créée
+	 * @param	src_image		emplacement et nom du fichier source
+	 * @param	dest_image		emplacement et nom de la miniature créée
+	 * @param	thumb_width		largeur de la miniature
+	 * @param	thumb_height	hauteur de la miniature
+	 * @param	quality			qualité de l'image
+	 * @return	boolean			vrai si image créée
 	 **/
-	public static function makeThumb($filename, $filename_out, $width, $height, $quality) {
+	public static function makeThumb($src_image, $dest_image, $thumb_width = 48, $thumb_height = 48, $jpg_quality = 90) {
 
 		if(!function_exists('imagecreatetruecolor')) return false;
 
-		# Informations sur l'image
-		list($width_orig,$height_orig,$type) = getimagesize($filename);
+		// Get dimensions of existing image
+		$image = getimagesize($src_image);
+
+		// Check for valid dimensions
+		if($image[0] <= 0 || $image[1] <= 0) return false;
+
+		// Determine format from MIME-Type
+		$image['format'] = strtolower(preg_replace('/^.*?\//', '', $image['mime']));
+
+		// calcul du ration si nécessaire
+		if($thumb_width!=$thumb_height) {
+			# Calcul du ratio
+			$x_offset = $y_offset = 0;
+			$square_size_w = $image[0];
+			$square_size_h = $image[1];
+			$ratio_w = $thumb_width / $image[0];
+			$ratio_h = $thumb_height / $image[1];
+			if($thumb_width == 0)
+				$thumb_width = $image[0] * $ratio_h;
+			elseif($thumb_height == 0)
+				$thumb_height = $image[1] * $ratio_w;
+			elseif($ratio_w < $ratio_h AND $ratio_w < 1) {
+				$thumb_width = $ratio_w * $image[0];
+				$thumb_height = $ratio_w * $image[1];
+			} elseif($ratio_h < 1) {
+				$thumb_width = $ratio_h * $image[0];
+				$thumb_height = $ratio_h * $image[1];
+			} else {
+				$thumb_width = $image[0];
+				$thumb_height = $image[1];
+			}
+		}
+
+		$canvas = imagecreatetruecolor($thumb_width, $thumb_height);
+
+		// Import image
+		switch( $image['format'] ) {
+			case 'jpg':
+			case 'jpeg':
+				$image_data = imagecreatefromjpeg($src_image);
+				break;
+			case 'png':
+				$image_data = imagecreatefrompng($src_image);
+				$color = imagecolortransparent($canvas, imagecolorallocatealpha($canvas, 0, 0, 0, 127));
+				imagefill($canvas, 0, 0, $color);
+				imagesavealpha($canvas, true);
+				break;
+			case 'gif':
+				$image_data = imagecreatefromgif($src_image);
+				$color = imagecolortransparent($canvas, imagecolorallocatealpha($canvas, 0, 0, 0, 127));
+				imagefill($canvas, 0, 0, $color);
+				imagesavealpha($canvas, true);
+			break;
+			default:
+				return false; // Unsupported format
+			break;
+		}
+
+		// Verify import
+		if($image_data == false) return false;
+
+		// Calculate measurements (square crop)
+		if($thumb_width==$thumb_height) {
+			if($image[0] > $image[1]) {
+				// For landscape images
+				$x_offset = ($image[0] - $image[1]) / 2;
+				$y_offset = 0;
+				$square_size_w = $square_size_h = $image[0] - ($x_offset * 2);
+			} else {
+				// For portrait and square images
+				$x_offset = 0;
+				$y_offset = ($image[1] - $image[0]) / 2;
+				$square_size_w = $square_size_h = $image[1] - ($y_offset * 2);
+			}
+		}
+
+		// Resize and crop
+		if( imagecopyresampled(
+			$canvas,
+			$image_data,
+			0,
+			0,
+			$x_offset,
+			$y_offset,
+			$thumb_width,
+			$thumb_height,
+			$square_size_w,
+			$square_size_h
+		)) {
+
+			// Create thumbnail
+			switch( strtolower(preg_replace('/^.*\./', '', $dest_image)) ) {
+				case 'jpg':
+				case 'jpeg':
+					return (imagejpeg($canvas, $dest_image, $jpg_quality) AND is_file($dest_image));
+				break;
+				case 'png':
+					return (imagepng($canvas, $dest_image) AND is_file($dest_image));
+				break;
+				case 'gif':
+					return (imagegif($canvas, $dest_image) AND is_file($dest_image));
+				break;
+				default:
+					return false; // Unsupported format
+				break;
+			}
 
-		# Calcul du ratio
-		$ratio_w = $width / $width_orig;
-		$ratio_h = $height / $height_orig;
-		if($width == 0)
-			$width = $width_orig * $ratio_h;
-		elseif($height == 0)
-			$height = $height_orig * $ratio_w;
-		elseif($ratio_w < $ratio_h AND $ratio_w < 1) {
-			$width = $ratio_w * $width_orig;
-			$height = $ratio_w * $height_orig;
-		} elseif($ratio_h < 1) {
-			$width = $ratio_h * $width_orig;
-			$height = $ratio_h * $height_orig;
 		} else {
-			$width = $width_orig;
-			$height = $height_orig;
+			return false;
 		}
 
-		# Création de l'image
-		$image_p = imagecreatetruecolor($width,$height);
-
-		if($type == 1) {
-			$image = imagecreatefromgif($filename);
-			$color = imagecolortransparent($image_p, imagecolorallocatealpha($image_p, 0, 0, 0, 127));
-			imagefill($image_p, 0, 0, $color);
-			imagesavealpha($image_p, true);
-			imagecopyresampled($image_p, $image, 0, 0, 0, 0, $width, $height, $width_orig, $height_orig);
-			imagegif($image_p, $filename_out);
-		}
-		elseif($type == 2) {
-			$image = imagecreatefromjpeg($filename);
-			imagecopyresampled($image_p, $image, 0, 0, 0, 0, $width, $height, $width_orig, $height_orig);
-			imagejpeg($image_p, $filename_out, $quality);
-		}
-		elseif($type == 3) {
-			$image = imagecreatefrompng($filename);
-			$color = imagecolortransparent($image_p, imagecolorallocatealpha($image_p, 0, 0, 0, 127));
-			imagefill($image_p, 0, 0, $color);
-			imagesavealpha($image_p, true);
-			imagecopyresampled($image_p, $image, 0, 0, 0, 0, $width, $height, $width_orig, $height_orig);
-			imagepng($image_p, $filename_out);
-		}
-
-		return is_file($filename_out);
 	}
 
 	/**
@@ -545,7 +608,7 @@ class plxUtils {
 			$length = sizeof($content) < $length ? sizeof($content) : $length;
 			return implode(' ',array_slice($content,0,$length)).$add_text;
 		} else { # On coupe la chaine en comptant le nombre de caractères
-			return strlen($str) > $length ? utf8_encode(substr(utf8_decode($str), 0, $length)).$add_text : $str;
+			return strlen($str) > $length ? utf8_decode(substr(utf8_encode($str), 0, $length)).$add_text : $str;
 		}
 	}
 
@@ -606,28 +669,26 @@ class plxUtils {
 	 * @param	base		url du site qui sera rajoutée devant les liens relatifs
 	 * @param	html		chaine de caractères à convertir
 	 * @return	string		chaine de caractères modifiée
-	 * @author	Stephane F., Amaury Graillat
+	 * @author	Stephane F., Amaury Graillat, J.P. Pourrez
 	 **/
 	public static function rel2abs($base, $html) {
 
-		// on protège les liens de type (href|src)="//" en doublant le caractère =
-		$html = preg_replace('@(href|src)=(["\']\/\/)@i', '\1==\2', $html);
-		// url des plugins
-		$html = preg_replace('@\<([^>]*) (href|src)=(["\'])[\.]/plugins@i', '<$1 $2=$3'.$base.'plugins', $html);
-		// generate server-only replacement for root-relative URLs
-		$server = preg_replace('@^([^:]+)://([^/]+)(/|$).*@', '\1://\2/', $base);
-		// on repare les liens ne commençant que part #
-		$get = plxUtils::getGets();
-		$html = preg_replace('@\<([^>]*) (href|src)=(["\'])#@i', '<\1 \2=\3'.$get.'#', $html);
-		// replace root-relative URLs
-		$html = preg_replace('@\<([^>]*) (href|src)=(["\']).?/@i', '<\1 \2=\3'.$server, $html);
-		// replace base-relative URLs
-		$html = preg_replace('@\<([^>]*) (href|src)=(["\'])([^:"]*|[^:"]*:[^/"][^"]*)(["\'])@i', '<\1 \2=\3'.$base.'\4\5', $html);
-		// unreplace fully qualified URLs with proto: that were wrongly added $base
-		$html = preg_replace('@\<([^>]*) (href|src)=(["\'])'.$base.'([a-zA-Z0-9]*):@i', '<\1 \2=\3\4:', $html);
-		// on rétablit les liens de type (href|src)="//" en remplaçant les caractères == par =
-		$html = preg_replace('@(href|src)==@i', '\1=', $html);
-		return $html;
+		if (substr($base, -1) != '/')
+			$base .= '/';
+
+		# on protège tous les liens externes au site, et on transforme tous les liens relatifs en absolus
+		# on ajoute le hostname si nécessaire
+		$mask = '=<<>>=';
+		$patterns = array('#(href)=("|\')(mailto:|news:)#i', '#(href|src)=("|\')([a-z]+://)#i', '#(href|src)=("|\')(?:\./)?([^/])#i');
+		$replaces = array('$1'.$mask.'$2$3', '$1'.$mask.'$2$3', '$1=$2'.$base.'$3');
+		if (preg_match('#^[a-z]+://#i', $base)) {
+			$patterns[] = '#(href|src)=("|\')/([^/])#i';
+			$replaces[] = '$1=$2'.$base.'$3';
+		}
+		$result = preg_replace($patterns, $replaces, $html);
+		# on retire la protection des liens externes. Expressions régulières lentes et inutiles
+		$result = str_replace($mask, '=', $result);
+		return $result;
 
 	}
 
@@ -903,6 +964,33 @@ class plxUtils {
 		return $buffer;
 	}
 
+	/**
+	 * Méthode qui converti les urls contenus dans une chaine en liens cliquables.
+	 *
+	 * @param	string		chaîne d'entrée
+	 * @param	string		Optionnel. Si spécifié, ce paramètre doit être un tableau associatif de format $arr['attribute'] = $value.
+	 * @return	string		Retourne une copie de la chaîne str dont les urls ont été encapsulées dans des balises <a>.
+	 * @author	http://code.seebz.net/p/autolink-php/
+	 *	Exemple 1:
+	 *		$str = 'A link : http://example.com/?param=value#anchor.';
+	 *		$str = autolink($str);
+	 *		echo $str; // A link : <a href="http://example.com/?param=value#anchor">http://example.com/?param=value#anchor</a>.
+	 *  Exemple 2:
+	 *		$str = 'http://example.com/';
+	 *		$str = autolink($str, array("target"=>"_blank","rel"=>"nofollow"));
+	 *		echo $str; // <a href="http://example.com/" target="_blank" rel="nofollow">http://example.com/</a>
+	 **/
+	public static function autolink($str, $attributes=array()) {
+		$attrs = '';
+		foreach ($attributes as $attribute => $value) {
+			$attrs .= " {$attribute}=\"{$value}\"";
+		}
+		$str = ' ' . $str;
+		$str = preg_replace('#([^"=\'>])((http|https|ftp)://[^\s<]+[^\s<\.)])#i', '$1<a href="$2"'.$attrs.'>$2</a>', $str);
+		$str = substr($str, 1);
+		return $str;
+	}
+
 /*
 	function arrayRemoveDuplicate($array, $field) {
 		foreach ($array as $element)
