@@ -1,21 +1,11 @@
 <?php
-# ------------------ BEGIN LICENSE BLOCK ------------------
-#
-# This file is part of PluXml : http://www.pluxml.org
-#
-# Copyright (c) 2010-2015 Stephane Ferrari and contributors
-# Copyright (c) 2008-2009 Florent MONTHEL and contributors
-# Copyright (c) 2006-2008 Anthony GUERIN
-# Licensed under the GPL license.
-# See http://www.gnu.org/licenses/gpl.html
-#
-# ------------------- END LICENSE BLOCK -------------------
-
 define('PLX_ROOT', './');
 define('PLX_CORE', PLX_ROOT.'core/');
 include(PLX_ROOT.'config.php');
 include(PLX_CORE.'lib/config.php');
 
+define('PLX_FEED', true);
+
 # On verifie que PluXml est installé
 if(!file_exists(path('XMLFILE_PARAMETERS'))) {
 	header('Location: '.PLX_ROOT.'install.php');
