@@ -27,7 +27,7 @@ $LANG = array(
 'TOP'					=> 'Top',
 
 # erreur.php
-'ERROR'					=> 'Ein Fehler ist erkannt geworden',
+'ERROR'					=> 'Ein Fehler ist aufgetreten',
 'BACKTO_HOME'			=> 'Zur&uuml;ck zur Homepage',
 
 # common
@@ -46,6 +46,11 @@ $LANG = array(
 'SEND'					=> 'Versenden',
 'COMMENTS_CLOSED'		=> 'Die Kommentare sind geschlossen',
 'ANTISPAM_WARNING'		=> 'Anti-Spam',
+
+'REPLY'					=> 'Antworten',
+'REPLY_TO'				=> 'Antworten',
+'CANCEL'				=> 'Abbrechen',
+
 );
 
 ?>
\ No newline at end of file
