@@ -46,6 +46,11 @@ $LANG = array(
 'SEND'					=> 'Trimite',
 'COMMENTS_CLOSED'		=> 'Comentariile sunt &#238;nchise',
 'ANTISPAM_WARNING'		=> 'Verificare anti-spam',
+
+'REPLY'					=> 'Răspuns',
+'REPLY_TO'				=> 'Răspuns',
+'CANCEL'				=> 'Anulare',
+
 );
 
 ?>
\ No newline at end of file
